/*
<DEPENDENCIES>
    <DEPENDS>Globals</DEPENDS>
    <DEPENDS>Browser</DEPENDS>
    <DEPENDS>Logger</DEPENDS>
    <DEPENDS>Snapshot</DEPENDS>
    <DEPENDS>Delta</DEPENDS>
    <DEPENDS>Alteration</DEPENDS>
    <DEPENDS>MouseMoveHandle</DEPENDS>
</DEPENDENCIES>
*/
function ScrollbarWidget( sId, sContainerDomId, sKnobDomId, bHorizontal, iMinSize, bLazyUpdate )
{
  if( sId )
  {
    this.init(sId, sContainerDomId, sKnobDomId, bHorizontal, iMinSize, bLazyUpdate);
  }
}
ScrollbarWidget.prototype.init = function( sId, sContainerDomId, sKnobDomId, bHorizontal, iMinSize, bLazyUpdate )
{
  ;
  this.sId = sId;
  this.containerDomId = sContainerDomId;
  this.knobDomId = sKnobDomId;
  this.horizontal = bHorizontal;
  if( iMinSize )
    this.minSize = iMinSize;
  else
    this.minSize = 3;
  this.lazyUpdate = bLazyUpdate;
  this.snapshotCount = 0;
  this.snapshot = null;
  this.knobState = null;
  this.nContainer = document.getElementById(this.containerDomId);
  this.nKnob = document.getElementById(this.knobDomId);
  this.knobPosition = 0.0;
  this.knobSize = 1.0;
  this.scrollBroker = null;
  this.aScrollingHandles = new Array();
  if( this.horizontal )
  {
    this.absPositioning = new AlterationLeft(this.sId + '_posAbs');
    this.relPositioning = new AlterationLeftRelative(this.sId + '_posRel');
    this.relResizing = new AlterationWidthRelative(this.sId + '_resize')
  }
  else
  {
    this.absPositioning = new AlterationTop(this.sId + '_posAbs');
    this.relPositioning = new AlterationTopRelative(this.sId + '_posRel');
    this.relResizing = new AlterationHeightRelative(this.sId + '_resize')
  }
  if( this.lazyUpdate )
  {
    this.startMoving = this.startMovingLazyUpdate;
    this.stopMoving = this.stopMovingLazyUpdate;
    this.doMove = this.doMoveLazyUpdate;
  }
  else
  {
    this.startMoving = this.startMovingImmediate;
    this.stopMoving = this.stopMovingImmediate;
    this.doMove = this.doMoveImmediate;
  }
  ScrollbarWidget.createMouseDownEventHandler(this);
  ScrollbarWidget.createMouseUpEventHandler(this);
  ScrollbarWidget.createMouseMoveEventHandler(this);
}
ScrollbarWidget.prototype.start = function()
{
  Browser.addEventListenerToDomNode(this.nKnob, Browser.eventNames.MOUSEDOWN, this.mouseDownHandler);
}
ScrollbarWidget.prototype.getId = function()
{
  return this.sId;
}
ScrollbarWidget.prototype.setScrollBroker = function( scrollBroker )
{
  this.scrollBroker = scrollBroker;
  this.scrollBroker.addPositionChangedHandle(this.getRepositionAction());
  this.scrollBroker.addSizeChangedHandle(this.getResizeAction());
}
ScrollbarWidget.prototype.addScrollingHandle = function( action )
{
  if( action )
    this.aScrollingHandles.push(action);
}
ScrollbarWidget.prototype.createSnapshot = function( node )
{
  return new Snapshot(this, this.snapshotCount++, node);
}
ScrollbarWidget.prototype.startMovingImmediate = function( mouseMoveHandle, event )
{
  this.snapshot = this.createSnapshot(this.nKnob);
}
ScrollbarWidget.prototype.stopMovingImmediate = function( mouseMoveHandle, event )
{
  this.snapshot = null;
}
ScrollbarWidget.prototype.doMoveImmediate = function( mouseMoveHandle, event )
{
  var delta = new Delta(event.clientX - mouseMoveHandle.downX, event.clientY - mouseMoveHandle.downY);
  var currentState = this.snapshot.clone();
  this.notifyPositionChange(currentState.add(this.absPositioning.alterAdequate(this.snapshot, delta)));
}
ScrollbarWidget.prototype.startMovingLazyUpdate = function( mouseMoveHandle, event )
{
  this.snapshot = this.createSnapshot(this.nKnob);
}
ScrollbarWidget.prototype.stopMovingLazyUpdate = function( mouseMoveHandle, event )
{
  this.notifyPositionChange(this.knobState);
  this.knobState = null;
  this.snapshot = null;
}
ScrollbarWidget.prototype.doMoveLazyUpdate = function( mouseMoveHandle, event )
{
  var delta = new Delta(event.clientX - mouseMoveHandle.downX, event.clientY - mouseMoveHandle.downY);
  var currentState = this.snapshot.clone();
  this.knobState = currentState.add(this.absPositioning.alterAdequate(this.snapshot, delta));
}
ScrollbarWidget.prototype.notifyPositionChange = function( knobSnapshot )
{
  this.knobPosition = ScrollbarWidget.calculateRelativePosition(
          this.nContainer, knobSnapshot, (this.horizontal ? 'x' : 'y' ));
  var position;
  if( ScrollbarWidget.hasHitTheBottom(this.nContainer, knobSnapshot, (this.horizontal ? 'x' : 'y' )) )
  {
    position = 1.0;
  }
  else
  {
    position = this.knobPosition;
  }
  if( this.scrollBroker )
    this.scrollBroker.scrollToRelativePosition(position);
  ScrollbarWidget.notifyListeners(this.aScrollingHandles, position);
}
ScrollbarWidget.prototype.reposition = function( position, snapshot )
{
  var delta;
  if( this.horizontal )
    delta = new Delta(position, 0.0);
  else
    delta = new Delta(0.0, position);
  if( snapshot )
    this.setContainerBounds(snapshot, this.knobSize);
  else
    this.setContainerBounds(this.createSnapshot(this.nContainer), this.knobSize);
  var knobSnapshot = this.createSnapshot(this.nKnob);
  knobSnapshot.add(this.relPositioning.alter(knobSnapshot, delta));
  this.knobPosition = position;
}
ScrollbarWidget.prototype.getRepositionAction = function( position )
{
  return new ObjectMethodAction(this, "reposition", position);
}
ScrollbarWidget.prototype.resize = function( size, snapshot )
{
  var delta;
  if( this.horizontal )
    delta = new Delta(size, 0.0);
  else
    delta = new Delta(0.0, size);
  if( snapshot )
    this.setContainerBounds(snapshot, size);
  else
    this.setContainerBounds(this.createSnapshot(this.nContainer), size);
  var knobSnapshot = this.createSnapshot(this.nKnob);
  knobSnapshot.add(this.relResizing.alter(knobSnapshot, delta));
  this.knobSize = size;
}
ScrollbarWidget.prototype.getResizeAction = function( size )
{
  return new ObjectMethodAction(this, "resize", size);
}
ScrollbarWidget.prototype.handleContainerAlteredEvent = function( snapshot )
{
  if( !snapshot )
    ;
  this.reposition(this.knobPosition, snapshot);
  this.resize(this.knobSize, snapshot);
}
ScrollbarWidget.prototype.setContainerBounds = function( snapshot, knobSize )
{
  if( this.horizontal )
    this.resetBounds(
            snapshot.left, snapshot.left + snapshot.width, this.minSize, snapshot.width, knobSize * snapshot.width);
  else
    this.resetBounds(
            snapshot.top, snapshot.top + snapshot.height, this.minSize, snapshot.height, knobSize * snapshot.height);
}
ScrollbarWidget.prototype.resetBounds = function( posLowerBound, posUpperBound, sizeLowerBound, sizeUpperBound,
                                                  knobLength )
{
  this.absPositioning.setLowerBound(posLowerBound);
  this.absPositioning.setUpperBound(posUpperBound - knobLength);
  this.relPositioning.setLowerBound(posLowerBound);
  this.relPositioning.setUpperBound(posUpperBound);
  this.relResizing.setLowerBound(sizeLowerBound);
  this.relResizing.setUpperBound(sizeUpperBound);
}
ScrollbarWidget.prototype.getHandleContainerAlteredAction = function( snapshot )
{
  return new ObjectMethodAction(this, "handleContainerAlteredEvent", snapshot);
}
ScrollbarWidget.calculateRelativePosition = function( nContainer, knobSnapshot, direction )
{
  var posContainer = new Point(0, 0);
  Browser.getAbsPos(nContainer, posContainer);
  var dimContainer = new Point(nContainer.offsetWidth, nContainer.offsetHeight);
  var posKnob = new Point(knobSnapshot.left, knobSnapshot.top);
  var position = (posKnob[direction] - posContainer[direction]) / dimContainer[direction];
  return position;
}
ScrollbarWidget.calculateRelativeSize = function( nContainer, knobSnapshot, direction )
{
  var dimContainer = new Point(nContainer.offsetWidth, nContainer.offsetHeight);
  var dimKnob = new Point(knobSnapshot.width, knobSnapshot.height);
  return dimKnob[direction] / dimContainer[direction];
}
ScrollbarWidget.hasHitTheBottom = function( nContainer, knobSnapshot, direction )
{
  var posContainer = new Point(0, 0);
  Browser.getAbsPos(nContainer, posContainer);
  var dimContainer = new Point(nContainer.offsetWidth, nContainer.offsetHeight);
  var posKnob = new Point(knobSnapshot.left, knobSnapshot.top);
  var dimKnob = new Point(knobSnapshot.width, knobSnapshot.height);
  var maxKnob = posKnob[direction] + dimKnob[direction];
  var maxContainer = posContainer[direction] + dimContainer[direction];
  var hasHit = maxKnob >= maxContainer;
  if( hasHit )
    ScrollbarWidget.debug(knobSnapshot.element, 'hasHitTheBottom(): '
            + 'maxKnob=' + maxKnob + ', maxContainer=' + maxContainer + ' => ' + hasHit);
  return hasHit;
}
ScrollbarWidget.notifyListeners = function( handles, param )
{
  for( var i = 0; i < handles.length; i++ )
  {
    handles[i].invoke(param);
  }
}
ScrollbarWidget.createMouseDownEventHandler = function( me )
{
  me.mouseDownHandler = function( event )
  {
    if( !event )
      event = window.event;
    Browser.removeEventListenerFromDomNode(me.nKnob, Browser.eventNames.MOUSEDOWN, me.mouseDownHandler);
    Browser.eventStopPropagation(event);
    Browser.eventPreventDefault(event);
    me.mouseMove = new MouseMoveHandle(event.clientX, event.clientY);
    Browser.addEventListenerToDocument(Browser.eventNames.MOUSEUP, me.mouseUpHandler);
    Browser.addEventListenerToDocument(Browser.eventNames.MOUSEMOVE, me.mouseMoveHandler);
    return false;
  }
}
ScrollbarWidget.createMouseUpEventHandler = function( me )
{
  me.mouseUpHandler = function( event )
  {
    if( !event )
      event = window.event;
    Browser.removeEventListenerFromDocument(Browser.eventNames.MOUSEMOVE, me.mouseMoveHandler);
    Browser.removeEventListenerFromDocument(Browser.eventNames.MOUSEUP, me.mouseUpHandler);
    me.mouseMove.stopMoving();
    me.stopMoving(me.mouseMove, event);
    me.mouseMove = undefined;
    Browser.addEventListenerToDomNode(me.nKnob, Browser.eventNames.MOUSEDOWN, me.mouseDownHandler);
  }
}
ScrollbarWidget.createMouseMoveEventHandler = function( me )
{
  me.mouseMoveHandler = function( event )
  {
    if( !event )
      event = window.event;
    if( !me.mouseMove.isMoving() )
    {
      me.startMoving(me.mouseMove, event);
      me.mouseMove.startMoving();
    }
    if( me.mouseMove.isMoving() )
    {
      me.doMove(me.mouseMove, event);
    }
  }
}
ScrollbarWidget.debug = function( nKnob, msg )
{
  try
  {
    if( nKnob.className == 'finder_scrollbar_knob' )
    {
      ;
    }
  }
  catch( e )
  {
    ;
  }
}
