/*
<DEPENDENCIES>
  <DEPENDS>Logger</DEPENDS>
</DEPENDENCIES>
*/
function ModelElementType( sId, sTypename, bRootType, oOpenMeasurementDialogAction, oMeasurementBean )
{
  if( sId )
  {
    this.init(sId, sTypename, bRootType, oOpenMeasurementDialogAction, oMeasurementBean);
  }
}
ModelElementType.prototype.init = function( sId, sTypename, bRootType, oOpenMeasurementDialogAction, oMeasurementBean )
{
  this.sId = sId;
  this.typename = sTypename;
  this.isRootType = ( bRootType == null ? false : bRootType );
  this.openDialogAction = oOpenMeasurementDialogAction;
  this.dataBean = oMeasurementBean;
}
ModelElementType.prototype.getId = function()
{
  return this.sId;
}
ModelElementType.prototype.getTypename = function()
{
  return this.typename;
}
ModelElementType.prototype.openMeasurementDialog = function()
{
  if( this.openDialogAction )
    this.openDialogAction.invoke();
}
ModelElementType.prototype.getMeasurementBean = function()
{
  return this.dataBean;
}
ModelElementType.prototype.clone = function()
{
  return new ModelElementType(
          this.sId + '_clone', this.typename, this.isRootType, this.openDialogAction, this.dataBean);
}
ModelElementType.prototype.isLoaded = function()
{
  return true;
}
ModelElementType.prototype.registerPropertyValue = function( property, value )
{
  if( property != null && value != null )
    this[property] = value;
}
function MeasurementBean( sId, sTypename, aFieldnames )
{
  if( sId )
  {
    this.init(sId, sTypename, aFieldnames);
  }
}
MeasurementBean.prototype.init = function( sId, sTypename, aFieldnames, aValues, aFieldValueHandles,
                                           aMessageSetHandles )
{
  this.sId = sId;
  this.typename = sTypename;
  this.aFieldnames = aFieldnames;
  if( aValues )
  {
    this.aValues = aValues;
  }
  else
  {
    this.aValues = new Array();
    for( var i = 0; i < this.aFieldnames.length; i++ )
    {
      this.aValues[this.aFieldnames[i]] = null;
    }
  }
  if( aFieldValueHandles )
    this.fieldValueHandles = aFieldValueHandles;
  else
    this.fieldValueHandles = new Array();
  if( aMessageSetHandles )
    this.aMessageSetHandles = aMessageSetHandles;
  else
    this.aMessageSetHandles = new Array();
}
MeasurementBean.prototype.getId = function()
{
  return this.sId;
}
MeasurementBean.prototype.clone = function()
{
  return new MeasurementBean(
          this.sId + '_clone', this.typename, this.aFieldnames, this.aValues,
          this.fieldValueHandles, this.aMessageSetHandles);
}
MeasurementBean.prototype.setValue = function( field, value )
{
  if( this.aValues[field] != undefined )
  {
    this.aValues[field] = value;
    var changeValueAction = this.fieldValueHandles[field];
    if( changeValueAction != undefined )
    {
      changeValueAction.invoke(this.aValues[field]);
    }
  }
}
MeasurementBean.prototype.getSetValueAction = function( fieldName, value )
{
  return new ObjectMethodAction(this, "setValue", fieldName, value);
}
MeasurementBean.prototype.getValue = function( value )
{
  return this.aValues[field];
}
MeasurementBean.prototype.updateValues = function( otherBean )
{
  for( var i = 0; i < this.aFieldnames.length; i++ )
  {
    if( otherBean[this.aFieldnames[i]] != undefined )
    {
      this.aValues[this.aFieldnames[i]] = otherBean[this.aFieldnames[i]];
      var changeValueAction = this.fieldValueHandles[this.aFieldnames[i]];
      if( changeValueAction != undefined )
      {
        changeValueAction.invoke(this.aValues[this.aFieldnames[i]]);
      }
    }
  }
  if( !otherBean.message )
    this.message = '';
  else
    this.message = otherBean.message;
  for( var i = 0; i < this.aMessageSetHandles.length; i++ )
  {
    this.aMessageSetHandles[i].invoke(this.message);
  }
}
MeasurementBean.prototype.getSetFieldValueAction = function( fieldName )
{
  return new ObjectMethodWithParameterAction(this, "setValueField", fieldName);
}
MeasurementBean.prototype.setValueField = function( fieldValue, fieldName )
{
  this.setValue(fieldName, fieldValue);
}
MeasurementBean.prototype.addValueSetHandle = function( fieldName, action )
{
  this.fieldValueHandles[fieldName] = action;
}
MeasurementBean.prototype.setMessage = function( message )
{
  this.message = message;
}
MeasurementBean.prototype.getSetMessageAction = function()
{
  return new ObjectMethodAction(this, "setMessage");
}
MeasurementBean.prototype.addMessageSetHandle = function( action )
{
  this.aMessageSetHandles.push(action);
}
MeasurementBean.prototype.toKeyValueString = function( sFieldSeparator )
{
  var result = '';
  for( var i = 0; i < this.aFieldnames.length; i++ )
  {
    if( result != '' )
      result += sFieldSeparator;
    result += this.aFieldnames[i] + "=" + this.aValues[this.aFieldnames[i]];
  }
  return "type=" + this.typename + sFieldSeparator + result;
}
MeasurementBean.prototype.toString = function()
{
  return "MeasurementBean{ " + this.toKeyValueString(", ") + " }";
}
function ModelElement( sId, sElementId, oType, oParent, aChildren )
{
  if( sId )
  {
    this.init(sId, sElementId, oType, oParent, aChildren);
  }
}
ModelElement.prototype.init = function( sId, sElementId, oType, oParent, aChildren )
{
  this.sId = sId;
  this.elementId = sElementId;
  this.type = oType
  this.parent = oParent;
  if( aChildren )
    this.aChildren = aChildren;
  else
    this.aChildren = new Array();
}
ModelElement.prototype.clone = function()
{
  return new ModelElement(this.sId + '_clone', this.elementId, this.type, this.parent, this.aChildren);
}
ModelElement.prototype.getId = function()
{
  return this.sId;
}
ModelElement.prototype.getElementId = function()
{
  return this.elementId;
}
ModelElement.prototype.setElementId = function( sElementId )
{
  this.elementId = sElementId;
}
ModelElement.prototype.getTypename = function()
{
  return this.type.getTypename();
}
ModelElement.prototype.isRootType = function()
{
  return this.type.isRootType;
}
ModelElement.prototype.openMeasurementDialog = function()
{
  if( this.type.openDialogAction )
    this.type.openDialogAction.invoke();
}
ModelElement.prototype.getMeasurementBean = function()
{
  return this.type.dataBean;
}
ModelElement.prototype.updateMeasurementData = function( someBean )
{
  return this.type.dataBean.updateValues(someBean);
}
ModelElement.prototype.addChild = function( modelElement )
{
  modelElement.parent = this;
  return this.aChildren[modelElement.getElementId()] = modelElement;
}
ModelElement.prototype.remove = function( sElementId )
{
  var element = this.find(sElementId);
  if( element )
  {
    element.clear();
    element.parent.removeChild(sElementId);
  }
}
ModelElement.prototype.removeChild = function( sElementId )
{
  if( this.aChildren[sElementId] != undefined )
    this.aChildren[sElementId] = undefined;
}
ModelElement.prototype.find = function( sElementId )
{
  if( sElementId == this.elementId )
  {
    return this;
  }
  else if( this.aChildren[sElementId] != undefined )
  {
    return this.aChildren[sElementId];
  }
  else
  {
    for( var i = 0; i < this.aChildren.length; i++ )
    {
      var descendant = this.aChildren[i].find(sElementId);
      if( descendant )
        return descendant;
    }
    return undefined;
  }
}
ModelElement.prototype.clear = function()
{
  for( var i = 0; i < this.aChildren.length; i++ )
    this.aChildren[i].clear();
  this.aChildren.length = 0;
}
function ConstructionModel( sId )
{
  if( sId )
  {
    this.init(sId);
  }
}
ConstructionModel.prototype.init = function( sId )
{
  ;
  this.sId = sId;
  this.root = null;
  this.aElementTypes = new Array();
  this.createdElements = 0;
}
ConstructionModel.prototype.getId = function()
{
  return this.sId;
}
ConstructionModel.prototype.registerElementType = function( oType )
{
  if( oType )
    this.aElementTypes[oType.getTypename()] = oType;
}
ConstructionModel.prototype.clear = function()
{
  if( this.root )
  {
    this.root.clear();
    this.root = null;
  }
}
ConstructionModel.prototype.setRoot = function( modelElement )
{
  this.clear();
  modelElement.parent = null;
  this.root = modelElement;
}
ConstructionModel.prototype.addElement = function( modelElement )
{
  if( this.root )
    this.root.addChild(modelElement);
}
ConstructionModel.prototype.removeElement = function( sElementId )
{
  if( this.root )
    this.root.remove(sElementId);
}
ConstructionModel.prototype.findElement = function( sElementId )
{
  if( this.root )
    return this.root.find(sElementId);
}
ConstructionModel.prototype.createElement = function( sElementId, sTypename )
{
  if( this.aElementTypes[sTypename] != undefined )
  {
    var type = this.aElementTypes[sTypename].clone();
    if( type )
    {
      return new ModelElement('element_' + this.createdElements++, sElementId, type, null, null);
    }
  }
}
ConstructionModel.prototype.rebuildRoot = function( sElementId, sTypename )
{
  if( this.aElementTypes[sTypename] != undefined )
  {
    var type = this.aElementTypes[sTypename].clone();
    if( type )
    {
      this.setRoot( new ModelElement('element_' + this.createdElements++, sElementId, type, null, null) );
    }
  }
}
ConstructionModel.prototype.rebuildElement = function( sElementId, sTypename )
{
  if( this.aElementTypes[sTypename] != undefined )
  {
    var type = this.aElementTypes[sTypename].clone();
    if( type )
    {
      this.addElement( new ModelElement('element_' + this.createdElements++, sElementId, type, null, null) );
    }
  }
}
