/*
<DEPENDENCIES>
  <DEPENDS>Logger</DEPENDS>
  <DEPENDS>DataModelViewBroker</DEPENDS>
</DEPENDENCIES>
*/
function DataModelView(sId)
{
	this.init(sId);
}
DataModelView.prototype.init = function(sId)
{
	this.sId = sId;
	this.slots = new Array();
	
	this.index = 0;
	this.initializedHandle = null;
	this.numberOfSlots = 0;
	this.scrolling = false;
	this.refreshIndex = -1;
	this.timer = null;
	this.selectedSlot = null;
}
DataModelView.prototype.getId = function()
{
	return this.sId;
}
DataModelView.prototype.setBroker = function(broker)
{
	this.broker = broker;
	this.broker.addNextElementsHandle(new ObjectMethodAction(this, "nextElements"))
	this.broker.addPreviousElementsHandle(new ObjectMethodAction(this, "previousElements"))
}
DataModelView.prototype.setModelItem = function(model)
{
	this.model = model;
}
DataModelView.prototype.registerSlot = function(slot)
{
	this.slots[this.numberOfSlots] = slot;
	slot.setManager(this);
	this.numberOfSlots++;
}
DataModelView.prototype.startDragAndDrop = function(product, position, event)
{
	this.model.mainManager.startDragAndDrop(product, position, event);
}
DataModelView.prototype.selected = function(slot)
{
	if (this.selectedSlot != null)
		this.selectedSlot.unSelected();
	this.selectedSlot = slot;
}
DataModelView.prototype.unSelected = function(slot)
{
	
}
DataModelView.prototype.start = function()
{
	this.changed();
}
DataModelView.prototype.getModelItem = function(index)
{
	if (index >= this.model.getNumberOfItems())
	{
		
		return null;
	}
	else
		return this.model.getModelItem(index)
}
DataModelView.prototype.changed = function(model, state)
{
	var startIndex = 0;
	if (state == "reload")
	{
		startIndex = this.index - this.numberOfSlots;
		;
	}
	else if (state == "refresh")
	{
		startIndex = this.index - this.numberOfSlots;
		if (this.scrolling == true)
		{
			this.refreshIndex = startIndex;
			return;
		}
	}
	this.index = startIndex;
	this.updateViewItems();
	
	if (state != "refresh")
		this.broker.dataChanged(this.model.getNumberOfItems(), startIndex, this.index - 1);
}
DataModelView.prototype.notifyItemChange = function(source, item)
{
	for (var i in this.slots)
	{
		var slot = this.slots[i];
		var model = slot.getModel();
		if (model == item)
		{
			slot.setModel(model);
			break;
		}
	}
}
DataModelView.prototype.nextElements = function(numberOfElements)
{
	this.scrolling = true;
	this.index = this.index - this.numberOfSlots + numberOfElements;
	this.updateViewItems();
	this.scrolling = false;
	if (this.refreshIndex != -1)
	{
		this.refrehIndex = -1;
		this.updateViewItems();
	}
}
DataModelView.prototype.previousElements = function(numberOfElements)
{
	this.scrolling = true;
	this.index = this.index - this.numberOfSlots - numberOfElements;
	this.updateViewItems();
	this.scrolling = false;
}
DataModelView.prototype.updateViewItems = function()
{
	if (this.timer)
		window.clearTimeout(this.timer);
	for (var i in this.slots)
	{
		var slot = this.slots[i];
		var cover = true;
		var productId = null;
		var loaded = false;
		var oldItem = slot.getModel();
		if (oldItem)
		{
			productId = oldItem.getProductId();
			loaded = oldItem.isLoaded();
		}
		var model = this.getModelItem(this.index);
		if (model != null && model.getProductId() == productId && model.isLoaded() == loaded)
			cover = false;
		if (cover)
			slot.cover();
		new SlotUpdater(slot, model);
		this.index++;
	}
	this.timer = window.setTimeout('SlotUpdaterAccess.instance.invoke()', 1);
}
DataModelView.prototype.getRunningUpdaterId = function()
{
	return this.runningUpdaterId;
}
function SlotUpdaterAccess()
{
	this.updater = new Array();
}
SlotUpdaterAccess.instance = new SlotUpdaterAccess();
SlotUpdaterAccess.prototype.addUpater = function(id, updater)
{
	this.updater[id] = updater;
}
SlotUpdaterAccess.prototype.removeUpater = function(id)
{
	this.updater[id] = null;
}
SlotUpdaterAccess.prototype.invoke = function()
{
	for (var i in this.updater)
		this.updater[i].updateSlot();
}
function SlotUpdater(slot, item)
{
	this.slot = slot;
	this.item = item;
	SlotUpdaterAccess.instance.addUpater(slot.getId(), this);
}
SlotUpdater.prototype.updateSlot = function()
{
	this.slot.setModel(this.item);
	this.slot.uncover();
}
