
/* /1175261643647_1.js

Logger.js
domapi/Globals.js
common/broker/Broker.js
actions/Actions.js
toolkit/staticexport/ServiceRegistryAccessor.js
toolkit/screen/ScreenBroker.js
toolkit/toggle/ToggleManagerStatic.js
toolkit/toggle/ToggleBroker.js
domapi/ServerResult.js
domapi/Browser.js
toolkit/screen/ScreenController.js
toolkit/pager/VisibilityBroker.js
toolkit/info/InformationVisibilityManager.js
toolkit/staticexport/ScoreStatistics.js
toolkit/achievement/AchievementStatistic.js
toolkit/achievement/AchievementManager.js
*/

/* Logger.js */
/*
<DEPENDENCIES>
</DEPENDENCIES>
*/
// Logger

/**
 * Defines the Logging class. This will usually be a single global instance
 *
 * @constructor
 */
function Logger()
{
	this.nFatal  = 0;
	this.nError =       this.nFatal + 1;
	this.nWarning =     this.nError + 1;
	this.nDebug =       this.nWarning + 1;
	this.nInfo =        this.nDebug + 1;
	this.nVerbose =     this.nInfo + 1;
	this.nTrace =       this.nVerbose + 1;
	this.nVeryVerbose = this.nTrace + 1;

	this.sDebugFrame = 'debugFrame';
	this.bActive = true;
	this.nLevel = this.nVeryVerbose;
	this.nLine = 0;
	this.sMask = '';

	this.aColor = new Array();
	this.aPrefix = new Array();
	this.aMask = new Array();

	this.aColor[this.nFatal]       = '#ff0000';
	this.aColor[this.nError]       = '#ff0000';
	this.aColor[this.nWarning]     = '#ff6666';
	this.aColor[this.nDebug]       = '#000000';
	this.aColor[this.nInfo]        = '#0000ff';
	this.aColor[this.nVerbose]     = '#588AB5';
	this.aColor[this.nTrace]       = '#785A95';
	this.aColor[this.nVeryVerbose] = '#006600';

	this.aPrefix[this.nFatal]       = 'Fatal&nbsp;&nbsp;';
	this.aPrefix[this.nError]       = 'Error&nbsp;&nbsp;';
	this.aPrefix[this.nWarning]     = 'Warning';
	this.aPrefix[this.nDebug]       = 'Debug&nbsp;&nbsp;';
	this.aPrefix[this.nInfo]        = 'Info&nbsp;&nbsp;&nbsp;';
	this.aPrefix[this.nVerbose]     = '.......';
	this.aPrefix[this.nTrace]       = 'Trace&nbsp;&nbsp;';
	this.aPrefix[this.nVeryVerbose] = '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';

  this.aHex = new Array();
  this.aHex[0] = '0';
  this.aHex[1] = '1';
  this.aHex[2] = '2';
  this.aHex[3] = '3';
  this.aHex[4] = '4';
  this.aHex[5] = '5';
  this.aHex[6] = '6';
  this.aHex[7] = '7';
  this.aHex[8] = '8';
  this.aHex[9] = '9';
  this.aHex[10] = 'a';
  this.aHex[11] = 'b';
  this.aHex[12] = 'c';
  this.aHex[13] = 'd';
  this.aHex[14] = 'e';
  this.aHex[15] = 'f';

  this.aModuleColor = new Array();
  
  this.lastLine = null; // for scrolling


  try
  {
  	if(!parent.frames[this.sDebugFrame])
  		this.bActive=false;
  }
  catch(e)
  {
  	this.bActive=false;
  }

  if ( this.bActive && parent.frames[this.sDebugFrame])
	{
		parent.frames[this.sDebugFrame].document.write('<html><head>\n');
		parent.frames[this.sDebugFrame].document.write('<link rel="stylesheet" href="../af-web/js/Logger.css" type="text/css">\n');
		parent.frames[this.sDebugFrame].document.write('</head><body>\n');
		parent.frames[this.sDebugFrame].document.write('<p class="Logger_Text">\n');
	}

  if ( this.bActive && parent.frames[this.sDebugFrame]) 
  {
    for (var i = this.nFatal; i <= this.nVeryVerbose; i++) 
    {
      this.aMask[i] = true;
    }
  }

	if ( this.bActive && parent.frames[this.sDebugFrame]) 
	{
		var sQuery = parent.document.location.search;
		sQuery = sQuery.substring(1, sQuery.length);
    var aArgs = sQuery.match(/([^=]+)\=([^&]+)/);

		if (aArgs != null)
		{
			for (var i = 1; i < aArgs.length; i++)
			{
				if (false) {} 
				else if (aArgs[i] == 'logmask')
				{
					i++;

          this.setLogMask(aArgs[i]);
				}
			}
		}
	}
	
}


/**
 * Set log mask from string. 
 *
 * @param sString mask string like "f,e,d,i,v,t,vv" or "-t,vv"
 */
Logger.prototype.setLogMask = function(sMask)
{
  var aName = new Array();
  aName[this.nFatal]       = 'f';
  aName[this.nError]       = 'e';
  aName[this.nWarning]     = 'w';
  aName[this.nDebug]       = 'd';
  aName[this.nInfo]        = 'i';
  aName[this.nVerbose]     = 'v';
  aName[this.nTrace]       = 't';
  aName[this.nVeryVerbose] = 'vv';

  this.sMask = sMask;

  for (var i = this.nFatal; i <= this.nVeryVerbose; i++) 
  {
    this.aMask[i] = true;
  }

  if (sMask == '')
  { 
    //
  }
  else 
  {
    var bValue = true;

    if (false) {}
    else if (sMask.substring(0, 1) == '-')
    {
      sMask = sMask.substring(1, sMask.length);
      bValue = false;
      for (var j = this.nFatal; j <= this.nVeryVerbose; j++) this.aMask[j] = true;
    }
    else
    {
      bValue = true;
      for (var j = this.nFatal; j <= this.nVeryVerbose; j++) this.aMask[j] = false;
    }

    aLogmask = sMask.split(',');
    for (var j = 0; j < aLogmask.length; j++)
    {
      var nLevel = -1;
      for (var k = this.nFatal; k <= this.nVeryVerbose; k++) 
      {
        if (aLogmask[j] == aName[k])
        {
          nLevel = k;
          break;
        }
      }
      if (nLevel >= 0) 
      {
        this.aMask[nLevel] = bValue;
      }
    }
  }
  
} 


/**
 * Return the log mask as string. 
 *
 */
Logger.prototype.getLogMask = function()
{
  var aName = new Array();
  aName[this.nFatal]       = 'f';
  aName[this.nError]       = 'e';
  aName[this.nWarning]     = 'w';
  aName[this.nDebug]       = 'd';
  aName[this.nInfo]        = 'i';
  aName[this.nVerbose]     = 'v';
  aName[this.nTrace]       = 't';
  aName[this.nVeryVerbose] = 'vv';
  
  var sMask = '';

  for (var i = this.nFatal; i <= this.nVeryVerbose; i++) 
  {
    if (this.aMask[i])
    {
      if (sMask != '') sMask += ',';
      sMask += aName[i];
    }
  }

  return sMask;
} 


Logger.prototype.getHex = function(nValue)
{
  var sValue = '';
  var nLow = nValue % 16;
  var nHigh = (nValue - nValue % 16) / 16;
  sValue = this.aHex[nHigh] + this.aHex[nLow];
  //alert(nValue+' '+nLow+' '+nHigh+' '+sValue);
  return sValue;
}

Logger.prototype.getModuleColor = function(sModule)
{
  if (this.aModuleColor[sModule] == null)
  {
    var sColor = '#000000';
    var nSum = 0;
    for (var i = 0; i < sModule.length; i++) 
    {
      var nChar = sModule.charCodeAt(i);
      nSum += parseInt(nChar);
    }
    var nRed = nSum % 171;
    var nGreen = nSum % 215;
    var nBlue = nSum % 191;
    this.aModuleColor[sModule] = '#' + this.getHex(nRed) + this.getHex(nGreen) + this.getHex(nBlue);
  }
  return this.aModuleColor[sModule];
}

/**
 * Generic print. 
 *
 * @param nLevel The debug level
 * @param sModule module name or class name that reports
 * @param sMessage log message, usually contains current METHOD and the actual message text
 */
Logger.prototype.print = function(nLevel, sModule, sMessage)
{
	if ( !this.bActive || !parent.frames[this.sDebugFrame]) return;

	if (nLevel <= this.nLevel && this.aMask[nLevel])
	{
		this.nLine++;
    var sColor = this.aColor[nLevel];
    
    var bBold = false;
    switch (nLevel)
    {
       case this.nFatal: bBold = true; break;
       case this.nError: bBold = true; break;
       //case this.nDebug: bBold = true; break;
      default: ;
    }
        
    if (!bBold) sColor = this.getModuleColor(sModule);
    
    switch (sModule)
    {
      case 'bla': sColor = '#123456'; break;
      default: ;
    }
    
    if (nLevel == this.nDebug)
    {
      sColor = '#0000ff';
    }
    
    var sOut = '<font id="Logger_' + (this.nLine) + '" color=\"' + sColor + '\">' + this.aPrefix[nLevel] + (bBold?'<b>':'') + ' [' + sModule + '] ' + sMessage + (bBold?'</b>':'') + '</font><br>\n';
		parent.frames[this.sDebugFrame].document.write(sOut);
		
    var o = parent.frames[this.sDebugFrame].document.getElementById('Logger_'+this.nLine);
    if (o != null) 
    {
      if (this.nLine % 20 == 0)
      {
        o.scrollIntoView(true);
        this.lastLine = null;
      }
      else
      {
        this.lastLine = o;
      }
    }
	}
  
} 


/**
 * Wrapper for fatal error messages. Fatal means program will not be able to continue.
 *
 * @param sModule see Logger.prototype.print
 * @param sMessage see Logger.prototype.print
 */
Logger.prototype.fatal = function(sModule, sMessage)
{
	if ( !this.bActive || !parent.frames[this.sDebugFrame]) return;
	this.print(this.nFatal, sModule, sMessage);
}



/**
 * Wrapper for error messages. Means something serious happens, but program will recover
 *
 * @param sModule see Logger.prototype.print
 * @param sMessage see Logger.prototype.print
 */
Logger.prototype.error = function(sModule, sMessage)
{
	if ( !this.bActive || !parent.frames[this.sDebugFrame]) return;
	this.print(this.nError, sModule, sMessage);
}


/**
 * Wrapper for warnings. A bad condition.
 *
 * @param sModule see Logger.prototype.print
 * @param sMessage see Logger.prototype.print
 */
Logger.prototype.warning = function(sModule, sMessage)
{
	if ( !this.bActive || !parent.frames[this.sDebugFrame]) return;
	this.print(this.nWarning, sModule, sMessage);
}


/**
 * Wrapper for debug output. Use this for temporary printf-debugging.
 *
 * @param sModule see Logger.prototype.print
 * @param sMessage see Logger.prototype.print
 */
Logger.prototype.debug = function(sModule, sMessage)
{
	if ( !this.bActive || !parent.frames[this.sDebugFrame]) return;
	this.print(this.nDebug, sModule, sMessage);
}


/**
 * Wrapper for info messages. Output important state changes. Expected to generate few lines per second
 *
 * @param sModule see Logger.prototype.print
 * @param sMessage see Logger.prototype.print
 */
Logger.prototype.info = function(sModule, sMessage)
{
	if ( !this.bActive || !parent.frames[this.sDebugFrame]) return;
	this.print(this.nInfo, sModule, sMessage);
}


/**
 * Wrapper for verbose output. Expected to generate 50 lines per second.
 *
 * @param sModule see Logger.prototype.print
 * @param sMessage see Logger.prototype.print
 */
Logger.prototype.verbose = function(sModule, sMessage)
{
	if ( !this.bActive || !parent.frames[this.sDebugFrame]) return;
	this.print(this.nVerbose, sModule, sMessage);
}


/**
 * Wrapper for method entry messages, optional exit messages.
 *
 * @param sModule see Logger.prototype.print
 * @param sMessage see Logger.prototype.print
 */
Logger.prototype.trace = function(sModule, sMessage)
{
	if ( !this.bActive || !parent.frames[this.sDebugFrame]) return;
		this.print(this.nTrace, sModule, sMessage);
}


/**
 * Wrapper for very verbose output. Expected to generate 1000 lines per second.
 *
 * @param sModule see Logger.prototype.print
 * @param sMessage see Logger.prototype.print
 */
Logger.prototype.veryverbose = function(sModule, sMessage)
{
	if ( !this.bActive || !parent.frames[this.sDebugFrame]) return;
		this.print(this.nVeryVerbose, sModule, sMessage);
}


Logger.prototype.scrollToLastLine = function()
{
  if (this.lastLine != null)
  {
    this.lastLine.scrollIntoView(true);
    this.lastLine = null;
  }
} 

Logger.prototype.objectTypeToString = function( object )
{
  if( object == undefined )
    return 'object is UNDEFINED';
  if( object == null )
    return 'object is NULL';

  return object.constructor;
}

Logger.prototype.objectToString = function( object, mode )
{
  if( object == undefined )
    return 'UNDEFINED';
  if( object == null )
    return 'NULL';
  // ---- doesn't work in IE.
  //  if( HTMLElement.prototype.isPrototypeOf(object) )
  //    return this.htmlElementToString(object);
  // ----
  if( object.tagName != undefined )
    return this.htmlElementToString(object);

  var result = '';

  if( mode == undefined || mode == null )
  {
    for( name in object )
    {
      if( result == '' )
        result += name;
      else
        result += ', ' + name;
    }

    if( result == '' )
      result = '{ -- NO ENUMERABLE PROPERTIES -- }';
    else
      result = '{ ' + result + ' }';
  }
  else if( mode == 'v' )
  {
    for( name in object )
    {
      result += name + '=' + object[name] + ';';
    }

    if( result == '' )
      result = '{ -- NO ENUMERABLE PROPERTIES -- }';
    else
      result = '{ ' + result + ' }';
  }
  else if( mode == 'vv' )
  {
    for( name in object )
    {
      result += name + '=' + this.objectToString(object[name], 'v') + ';';
    }

    if( result == '' )
      result = '{ -- NO ENUMERABLE PROPERTIES -- }';
    else
      result = '{ ' + result + ' }';
  }

  return result;
}

Logger.prototype.htmlElementToString = function( object )
{
  if( object == undefined )
    return 'UNDEFINED';
  if( object == null )
    return 'NULL';

  return '{ tagName=' + object.tagName
          + (object.id == undefined ? '' : (object.id == null ? '' : '; id=' + object.id))
          + (object.className == undefined ? '' : (object.className == null ? '' : '; className=' + object.className))
          + ' }';
}


// Greate a static instance
Log = new Logger();
setInterval('Log.scrollToLastLine()', 1000);

// Check the logger
Log.info('main', 'Logger starting with mask=' + Log.getLogMask());


/* domapi/Globals.js */
/*
<DEPENDENCIES>
</DEPENDENCIES>
*/
function Point(x,y)
{
  this.x = x;
  this.y = y;
}
Point.prototype.toString = function()
{
  return 'Point{ x=' + this.x + ', y=' + this.y + ' }';
}
function shuffleArray(a)
{
  var aLinearValue = new Array();
  var aLinearUsed = new Array();
  for (var i = 0; i < a.length; i++)
  {
    aLinearValue[i] = a[i];
    aLinearUsed[i] = false;
  }
  var nLow = 0;
  var nHigh = a.length - 1;
  for (var i = 0; i < a.length; i++)
  {
    nRandomIndex = Math.round( (nLow - 0.5) +( ( (nHigh+0.49999) - (nLow-0.5) ) * Math.random() ) );
    var bFoundUnused = false;
    while (!bFoundUnused)
    {
      if (! aLinearUsed[nRandomIndex])
      {
        bFoundUnused = true;
        aLinearUsed[nRandomIndex] = true; 
        break;
      }
      else
      {
        nRandomIndex++;
        if (nRandomIndex > nHigh) nRandomIndex = nLow;
      }
    }
    a[i] = aLinearValue[nRandomIndex];
  }
}

/* common/broker/Broker.js */
/*
<DEPENDENCIES>
    <DEPENDS>Logger</DEPENDS>
    <DEPENDS>Globals</DEPENDS>
</DEPENDENCIES>
*/
function BrokerActionPipeline()
{
  this.callstack = new Array();
  this.pipeline = new Array();
  this.blockingTasks = new Array();
  this.finalAction = null;
  this.blockCounter = 0;
}
BrokerActionPipeline.prototype.beginAction = function(key)
{
  ;
  this.callstack.push(key);
}
BrokerActionPipeline.prototype.endAction = function(key)
{
  ;
  var closedBrokerKey = this.callstack[this.callstack.length -1];
  if(key != closedBrokerKey)
  {
    ;
  }
  else
  {
    this.callstack.pop();
  }
  this.executePipeline();
}
BrokerActionPipeline.prototype.executePipeline = function()
{
  if((this.callstack.length == 0) && (this.blockCounter == 0))
  {
    this.nextScheduledAction();
  }
}
BrokerActionPipeline.prototype.block = function(key)
{
  ;
  if(!this.blockingTasks[key])
  {
    this.blockingTasks[key] = true;
    this.blockCounter++;
  }
}
BrokerActionPipeline.prototype.unblock = function(key)
{
  ;
  if(this.blockingTasks[key])
  {
    this.blockingTasks[key] = false;
    this.blockCounter--;
  }
  this.executePipeline();
}
BrokerActionPipeline.prototype.scheduleFinalAction = function(action, parameterArray)
{
  ;
  if(this.finalAction)
  {
    ;
  }
  else
  {
    var actionObject = new Object();
    actionObject.action = action;
    actionObject.parameterArray = parameterArray;
    this.finalAction = actionObject;
  }
}
BrokerActionPipeline.prototype.scheduleAction = function(action, parameterArray)
{
  ;
  var actionObject = new Object();
  actionObject.action = action;
  actionObject.parameterArray = parameterArray;
  this.pipeline.push(actionObject);
  this.executePipeline();
}
BrokerActionPipeline.prototype.nextScheduledAction = function()
{
  ;
  if(this.pipeline.length > 0)
  {
    ;
    var actionObject = this.pipeline.shift();
    BrokerActions_callAction(actionObject.action, actionObject.parameterArray);
    this.executePipeline();
  }
  else if(this.finalAction)
  {
    ;
    var callAction = this.finalAction;
    this.finalAction = null;
    BrokerActions_callAction(callAction.action, callAction.parameterArray);
  }
}
function BrokerActions()
{
   this.init()
}
BrokerActions.prototype.init = function(name)
{
  this.actions = new Array();
}
BrokerActions.prototype.callActions = function(parameterArray)
{
  for(id in this.actions)
  {
    var action = this.actions[id];
    BrokerActions_callAction(action, parameterArray);
  }
}
BrokerActions.prototype.addAction = function(action)
{
  this.actions.push(action);
}
function BrokerActions_callAction(action, parameterArray)
{
  if(parameterArray)
  {
    action.invoke(
      parameterArray[0],
      parameterArray[1],
      parameterArray[2],
      parameterArray[3],
      parameterArray[4],
      parameterArray[5],
      parameterArray[6],
      parameterArray[7],
      parameterArray[8]);
  }
  else
  {
    action.invoke();
  }
}
function Broker(name)
{
  this.init(name)
}
Broker.actionPipeline = new BrokerActionPipeline();
Broker.prototype.init = function(name)
{
  this.name = name;
  this.callbacks = new Array();
}
Broker.prototype.getMessage = function(message, parameterArray)
{
  var key = this.name + '_' + message;
  Broker.actionPipeline.beginAction(key);
  var callback = this.callbacks[message];
  if(callback)
  {
    callback.callActions(parameterArray);
  }
  Broker.actionPipeline.endAction(key);
}
Broker.prototype.register = function(match, obj, callback)
{
  ;
}
Broker.prototype.registerAction = function(match, action)
{
  var callback = this.callbacks[match];
  if(!callback)
  {
    callback = new BrokerActions();
    this.callbacks[match] = callback;
  }
  callback.addAction(action);
}

/* actions/Actions.js */
/*
<DEPENDENCIES>
  <DEPENDS>Broker</DEPENDS>
</DEPENDENCIES>
*/
function ChangeImageAction(domId, url)
{
    this.domId = domId;
    this.url = url;
}
ChangeImageAction.prototype.invoke = function()
{
    document.getElementById(this.domId).src=this.url;
}
function SetStyleAction(domId, property, value)
{
    this.domId = domId;
    this.property = property;
    this.value = value;
}
SetStyleAction.prototype.invoke = function()
{
    document.getElementById(this.domId).style[this.property] = this.value;
}
function ObjectMethodAction(objectName, methodname, param1, param2, param3, param4, param5, param6, param7)
{
    this.objectName= objectName;
    this.methodname = methodname;
    this.param1 = param1;
    this.param2 = param2;
    this.param3 = param3;
    this.param4 = param4;
    this.param5 = param5;
    this.param6 = param6;
    this.param7 = param7;
}
ObjectMethodAction.prototype.invoke = function(parameter1, parameter2, parameter3, parameter4, parameter5, parameter6, parameter7)
{
    if (typeof parameter1 != 'undefined')
        return this.objectName[this.methodname](parameter1, parameter2, parameter3, parameter4, parameter5, parameter6, parameter7);
    else
        return this.objectName[this.methodname](this.param1, this.param2, this.param3, this.param4, this.param5, this.param6, this.param7);
}
function ObjectMethodWithParameterAction(objectName, methodname, param1, param2, param3, param4, param5, param6, param7)
{
    this.objectName= objectName;
    this.methodname = methodname;
    this.param1 = param1;
    this.param2 = param2;
    this.param3 = param3;
    this.param4 = param4;
    this.param5 = param5;
    this.param6 = param6;
    this.param7 = param7;
}
ObjectMethodWithParameterAction.prototype.invoke = function(parameter1)
{
    if (typeof parameter1 != 'undefined')
        return this.objectName[this.methodname](parameter1, this.param1, this.param2, this.param3, this.param4, this.param5, this.param6, this.param7);
    else
        return this.objectName[this.methodname](this.param1, this.param2, this.param3, this.param4, this.param5, this.param6, this.param7);
}
function SyncObjectMethodAction(objectName, methodname, param1, param2, param3, param4, param5, param6, param7)
{
    this.objectName= objectName;
    this.methodname = methodname;
    this.param1 = param1;
    this.param2 = param2;
    this.param3 = param3;
    this.param4 = param4;
    this.param5 = param5;
    this.param6 = param6;
    this.param7 = param7;
}
SyncObjectMethodAction.prototype.invoke = function(parameter1, parameter2, parameter3, parameter4, parameter5, parameter6, parameter7)
{
  Broker.actionPipeline.scheduleAction(new ObjectMethodAction(this, "invokeTarget"), [parameter1, parameter2, parameter3, parameter4, parameter5, parameter6, parameter7]);
}
SyncObjectMethodAction.prototype.invokeTarget = function(parameter1, parameter2, parameter3, parameter4, parameter5, parameter6, parameter7)
{
    if (typeof parameter1 != 'undefined')
        return this.objectName[this.methodname](parameter1, parameter2, parameter3, parameter4, parameter5, parameter6, parameter7);
    else
        return this.objectName[this.methodname](this.param1, this.param2, this.param3, this.param4, this.param5, this.param6, this.param7);
}
function FinalObjectMethodAction(objectName, methodname, param1, param2, param3, param4, param5, param6, param7)
{
    this.objectName= objectName;
    this.methodname = methodname;
    this.param1 = param1;
    this.param2 = param2;
    this.param3 = param3;
    this.param4 = param4;
    this.param5 = param5;
    this.param6 = param6;
    this.param7 = param7;
}
FinalObjectMethodAction.prototype.invoke = function(parameter1, parameter2, parameter3, parameter4, parameter5, parameter6, parameter7)
{
  Broker.actionPipeline.scheduleFinalAction(new ObjectMethodAction(this, "invokeTarget"), [parameter1, parameter2, parameter3, parameter4, parameter5, parameter6, parameter7]);
}
FinalObjectMethodAction.prototype.invokeTarget = function(parameter1, parameter2, parameter3, parameter4, parameter5, parameter6, parameter7)
{
    if (typeof parameter1 != 'undefined')
        return this.objectName[this.methodname](parameter1, parameter2, parameter3, parameter4, parameter5, parameter6, parameter7);
    else
        return this.objectName[this.methodname](this.param1, this.param2, this.param3, this.param4, this.param5, this.param6, this.param7);
}
function IgnoreRuntimeParameterAction(objectName, methodname, param1, param2, param3, param4, param5, param6, param7)
{
    this.objectName= objectName;
    this.methodname = methodname;
    this.param1 = param1;
    this.param2 = param2;
    this.param3 = param3;
    this.param4 = param4;
    this.param5 = param5;
    this.param6 = param6;
    this.param7 = param7;
}
IgnoreRuntimeParameterAction.prototype.invoke = function()
{
    return this.objectName[this.methodname](this.param1, this.param2, this.param3, this.param4, this.param5, this.param6, this.param7);
}
function AlertAction(text)
{
    this.text = text;
}
AlertAction.prototype.invoke = function()
{
    alert(this.text);
}
function SolvedAction(objectName, methodname)
{
    this.objectName = objectName;
    this.methodname = methodname;
}
SolvedAction.prototype.invoke = function(para1, para2, para3, para4, para5, para6, para7, para8)
{
    this.object[this.methodname](para1, para2, para3, para4, para5, para6, para7, para8); 
}
function DoNothingAction()
{
}
DoNothingAction.prototype.invoke = function()
{
}

/* toolkit/staticexport/ServiceRegistryAccessor.js */
 /*
 <DEPENDENCIES>
	 <DEPENDS>Logger</DEPENDS>
 </DEPENDENCIES>
 */
 function ServiceRegistryAccessor()
 {
 }
 ServiceRegistryAccess = new ServiceRegistryAccessor();
 ServiceRegistryAccessor.prototype.getServiceRegistry= function() {
	var serviceRegistry = null;
	
	if (parent.frames['services'] && parent.frames['services'].serviceregistry)
		serviceRegistry =  parent.frames['services'].serviceregistry;
	else if(opener && opener.parent && opener.parent.frames['services'] && opener.parent.frames['services'].serviceregistry)
		serviceRegistry =  opener.parent.frames['services'].serviceregistry;
	return serviceRegistry; 	
 }

/* toolkit/screen/ScreenBroker.js */
/*
<DEPENDENCIES>
    <DEPENDS>Logger</DEPENDS>
    <DEPENDS>Actions</DEPENDS>
    <DEPENDS>Broker</DEPENDS>
    <DEPENDS>IgnoreRuntimeParameterAction</DEPENDS>
    <DEPENDS>ServiceRegistryAccessor</DEPENDS>
</DEPENDENCIES>
*/
ScreenBroker.prototype             = new Broker();
ScreenBroker.prototype.constructor = ScreenBroker;
ScreenBroker.superclass            = Broker.prototype;
function ScreenBroker()
{
    ;
    this.screenController = null;
    this.bookmarkable = false;
     ScreenBroker.superclass.init.call(this, 'ScreenBroker');
     window.screenBroker = this;
     this.beforeLeavePageAction = null;
}
ScreenBroker.prototype.setScreenController = function(screenController)
{
    this.screenController = screenController;
}
ScreenBroker.prototype.getId = function()
{
    return 'ScreenBroker';
}
ScreenBroker.prototype.doReplace = function(extURL)
{
    ;
    var paramArray = new Array();
    paramArray[0] = extURL;
    this.getMessage('replace', paramArray);
}
ScreenBroker.prototype.addReplaceHandle = function(action)
{
    this.registerAction('replace', action);
}
ScreenBroker.prototype.getReplaceAction = function(extURL)
{
    return new ObjectMethodAction(this, 'replace', extURL);
}
ScreenBroker.prototype.replace = function(extURL)
{
    if (this.screenController)
        this.screenController.shouldReplace(extURL);
    else
        this.doReplace(extURL);
}
ScreenBroker.prototype.doReload = function()
{
    ;
    this.getMessage('reload');
}
ScreenBroker.prototype.addReloadHandle = function(action)
{
    this.registerAction('reload', action);
}
ScreenBroker.prototype.getReloadAction = function()
{
    return new ObjectMethodAction(this, 'reload');
}
ScreenBroker.prototype.reload = function()
{
    if (this.screenController)
        this.screenController.shouldReload();
    else
        this.doReload();
}
ScreenBroker.prototype.doPopup = function(extURL, windowName, width, height, scrollbars, resizable)
{
    ;
    var paramArray = new Array();
    paramArray[0] = extURL;
    paramArray[1] = windowName;
    paramArray[2] = width;
    paramArray[3] = height;
    paramArray[4] = scrollbars;
    paramArray[5] = resizable;
    this.getMessage('popup', paramArray);
}
ScreenBroker.prototype.addPopupHandle = function(action)
{
    this.registerAction('popup', action);
}
ScreenBroker.prototype.getPopupAction = function(id, extURL, windowName, width, height, scrollbars, resizable)
{
    return new ObjectMethodAction(this, 'popup',
                id, extURL, windowName, width, height, scrollbars, resizable);
}
ScreenBroker.prototype.popup = function(id, extURL, windowName, width, height, scrollbars, resizable)
{
    extURL = this.getURL(id, extURL);
    if (this.screenController)
        this.screenController.shouldPopup(extURL, windowName, width, height, scrollbars, resizable)
    else
        this.doPopup(extURL, windowName, width, height, scrollbars, resizable)
}
ScreenBroker.prototype.doIFrame = function(extURL, windowName)
{
    ;
    var paramArray = new Array();
    paramArray[0] = extURL;
    paramArray[1] = windowName;
    this.getMessage('iframe', paramArray);
}
ScreenBroker.prototype.addIFrameHandle = function(action)
{
    this.registerAction('iframe', action);
}
ScreenBroker.prototype.getIFrameAction = function(extURL, windowName)
{
    return new ObjectMethodAction(this, 'iframe',
                extURL, windowName);
}
ScreenBroker.prototype.iframe = function(extURL, windowName)
{
    if (this.screenController)
        this.screenController.shouldIFrame(extURL, windowName)
    else
        this.doIFrame(extURL, windowName)
}
ScreenBroker.prototype.doInvokeServletMethod = function(extURL)
{
    ;
    var paramArray = new Array();
    paramArray[0] = extURL;
    this.getMessage('invokeServletMethod', paramArray);
}
ScreenBroker.prototype.addInvokeServletMethodHandle = function(action)
{
    this.registerAction('invokeServletMethod', action);
}
ScreenBroker.prototype.getInvokeServletMethodAction = function(extURL, successAction, errorAction)
{
    return new ObjectMethodAction(this, 'invokeServletMethod', extURL, successAction, errorAction);
}
ScreenBroker.prototype.invokeServletMethod = function(extURL, callBackAction, errorAction)
{
    if (this.screenController)
        this.screenController.shouldInvokeServletMethod(extURL, callBackAction, errorAction)
    else
        this.doInvokeServletMethod(extURL)
}
ScreenBroker.prototype.doCallServer = function(extURL)
{
    ;
    var paramArray = new Array();
    paramArray[0] = extURL;
    this.getMessage('callServer', paramArray);
}
ScreenBroker.prototype.addCallServerHandle = function(action)
{
    this.registerAction('callServer', action);
}
ScreenBroker.prototype.getCallServerAction = function(extURL, successAction, errorAction)
{
    return new ObjectMethodAction(this, 'callServer', extURL, successAction, errorAction);
}
ScreenBroker.prototype.callServer = function(extURL, callBackAction, errorAction)
{
    if (this.screenController)
        this.screenController.shouldCallServer(extURL, callBackAction, errorAction)
    else
        this.doCallServer(extURL)
}
ScreenBroker.prototype.doClosePopup = function(windowName)
{
    ;
    var paramArray = new Array();
    paramArray[0] = windowName;
    this.getMessage('closePopup', paramArray);
}
ScreenBroker.prototype.addClosePopupHandle = function(action)
{
    this.registerAction('closePopup', action);
}
ScreenBroker.prototype.getClosePopupAction = function(windowName)
{
    return new ObjectMethodAction(this, 'closePopup', windowName);
}
ScreenBroker.prototype.closePopup = function(windowName)
{
    if (this.screenController)
        this.screenController.shouldClosePopup(windowName)
    else
        this.doClosePopup(windowName)
}
ScreenBroker.prototype.doReloadPopup = function(extURL, windowName)
{
    ;
    var paramArray = new Array();
    paramArray[0] = extURL;
    paramArray[1] = windowName;
    this.getMessage('reloadPopup', paramArray);
}
ScreenBroker.prototype.addReloadPopupHandle = function(action)
{
    this.registerAction('reloadPopup', action);
}
ScreenBroker.prototype.getReloadPopupAction = function(extURL, windowName)
{
    return new ObjectMethodAction(this, 'reloadPopup', extURL, windowName);
}
ScreenBroker.prototype.reloadPopup = function(extURL, windowName)
{
    if (this.screenController)
        this.screenController.shouldReloadPopup(extURL, windowName)
    else
        this.doReloadPopup(extURL, windowName)
}
ScreenBroker.prototype.doLoaded = function()
{
    ;
    this.getMessage('loaded');
}
ScreenBroker.prototype.addLoadedHandle = function(action)
{
    this.registerAction('loaded', action);
}
ScreenBroker.prototype.getLoadedAction = function()
{
    return new ObjectMethodAction(this, 'loaded');
}
ScreenBroker.prototype.loaded = function()
{
    if (this.screenController)
        this.screenController.shouldLoaded();
    else
        this.doLoaded();
}
ScreenBroker.prototype.doUnload = function()
{
    ;
    this.getMessage('unloaded');
}
ScreenBroker.prototype.addUnloadHandle = function(action)
{
    this.registerAction('unloaded', action);
}
ScreenBroker.prototype.getUnloadAction = function()
{
    return new ObjectMethodAction(this, 'unloaded');
}
ScreenBroker.prototype.unloaded = function()
{
    if (this.screenController)
        this.screenController.shouldUnload();
    else
        this.doUnload();
}
ScreenBroker.prototype.doOpenWindow = function(url, target)
{
    ;
    var paramArray = new Array();
    paramArray[0] = url;
    paramArray[1] = target;
    this.getMessage('openWindow', paramArray);
}
ScreenBroker.prototype.addOpenWindowHandle = function(action)
{
    this.registerAction('openWindow', action);
}
ScreenBroker.prototype.getOpenWindowAction = function(id, url, target)
{
    return new ObjectMethodAction(this, 'openWindow', id, url, target);
}
ScreenBroker.prototype.openWindow = function(id, url, target)
{
    url = this.getURL(id, url);
    if (this.screenController)
        this.screenController.shouldOpenWindow(url, target);
    else
        this.doOpenWindow(url, target);
}
ScreenBroker.prototype.doOpenerReplace = function(internalURL)
{
    ;
    var paramArray = new Array();
    paramArray[0] = internalURL;
    this.getMessage('openerReplace', paramArray);
}
ScreenBroker.prototype.addOpenerReplaceHandle = function(action)
{
    this.registerAction('openerReplace', action);
}
ScreenBroker.prototype.getOpenerReplaceAction = function(internalURL)
{
    return new ObjectMethodAction(this, 'openerReplace', internalURL);
}
ScreenBroker.prototype.openerReplace = function(internalURL)
{
    if (this.screenController)
        this.screenController.shouldOpenerReplace(internalURL);
    else
        this.doOpenerReplace(internalURL);
}
ScreenBroker.prototype.getAddUserMarkerOpenerAction = function(markerId)
{
    var obj = new Object();
    obj.invoke = function()
    {
        if (opener && opener.screenBroker)
            opener.screenBroker.addUserMarker(markerId);
    };
    return obj;
}
ScreenBroker.prototype.getAddUserMarkerAction = function(markerId)
{
    return new ObjectMethodAction(this, 'addUserMarker', markerId);
}
ScreenBroker.prototype.addUserMarker = function(markerId)
{
    ;
    if (this.screenController)
        this.screenController.shouldAddUserMarker(markerId);
    else
        this.doAddUserMarker(markerId);
}
ScreenBroker.prototype.doAddUserMarker = function(markerId)
{
    var paramArray = new Array();
    paramArray[0] = markerId;
    this.getMessage('addUserMarker', paramArray);
}
ScreenBroker.prototype.addAddUserMarkerHandle = function(action)
{
    this.registerAction('addUserMarker', action);
}
ScreenBroker.prototype.setBookmarkable = function(bookmarkEnable)
{
    ;
    this.bookmarkable = bookmarkEnable;
}
ScreenBroker.prototype.doNotifyPopupAware = function(screenBroker)
{
    ;
    var paramArray = new Array();
    paramArray[0] = screenBroker;
    this.getMessage('notifyPopupAware', paramArray);
}
ScreenBroker.prototype.addNotifyPopupAwareHandle = function(action)
{
    this.registerAction('notifyPopupAware', action);
}
ScreenBroker.prototype.getNotifyPopupAwareAction = function(screenBroker)
{
    return new ObjectMethodAction(this, 'notifyPopupAware', screenBroker);
}
ScreenBroker.prototype.notifyPopupAware = function(screenBroker)
{
    if (this.screenController)
        this.screenController.shouldNotifyPopupAware(screenBroker)
    else
        this.doNotifyPopupAware(screenBroker)
}
ScreenBroker.prototype.doRequestLogout = function()
{
    ;
    this.getMessage('requestLogout');
}
ScreenBroker.prototype.addRequestLogoutHandle = function(action)
{
    this.registerAction('requestLogout', action);
    window.Quit = function()
    {
        window.screenBroker.getRequestLogoutAction().invoke();
    }
}
ScreenBroker.prototype.getRequestLogoutAction = function()
{
    return new ObjectMethodAction(this, 'requestLogout');
}
ScreenBroker.prototype.requestLogout = function()
{
    this.doRequestLogout();
}
ScreenBroker.prototype.doLogout = function()
{
    ;
    this.getMessage('logout');
}
ScreenBroker.prototype.getLogoutAction = function()
{
    return new ObjectMethodAction(this, 'logout');
}
ScreenBroker.prototype.addLogoutHandle = function(action)
{
    this.registerAction('logout', action);
}
ScreenBroker.prototype.logout = function()
{
    if (this.screenController)
        this.screenController.shouldLogout();
    else
        this.doLogout();
}
ScreenBroker.prototype.doLeave = function(screenBroker)
{
    ;
    var paramArray = new Array();
    paramArray[0] = screenBroker;
    this.getMessage('leave', paramArray);
}
ScreenBroker.prototype.addLeaveHandle = function(action)
{
    this.registerAction('leave', action);
}
ScreenBroker.prototype.getLeaveAction = function(screenBroker)
{
    return new ObjectMethodAction(this, 'leave', screenBroker);
}
ScreenBroker.prototype.leave = function(screenBroker)
{
    if (this.screenController)
        this.screenController.shouldLeave(screenBroker)
    else
        this.doLeave(screenBroker)
}
ScreenBroker.prototype.getURL = function(id, defaulturl)
{
	
	if (id)
    {
		var serviceregistry = ServiceRegistryAccess.getServiceRegistry();
		if (serviceregistry)
		{
			var linkservice = serviceregistry.getService("linkservice");
			if (linkservice)
			{
				var url = linkservice.getLink(id);
				if (url)
					defaulturl = url;
			}
		}
   	}
   	return defaulturl;
}

/* toolkit/toggle/ToggleManagerStatic.js */
 /*
 <DEPENDENCIES>
   <DEPENDS>Logger</DEPENDS>
   <DEPENDS>ScreenBroker</DEPENDS>
   <DEPENDS>ServiceRegistryAccessor</DEPENDS>
 </DEPENDENCIES>
 */
 function ToggleManagerStatic(sId, propertyKey)
 {
 if (sId) { this.init(sId, propertyKey); }
 }
 ToggleManagerStatic.prototype.init = function(sId, propertyKey)
 {
	this.sId = sId;
	this.propertyKey = propertyKey;
	this.initService();
	if (this.propertyservice && this.propertyservice.getPropertyValue(propertyKey))
	{
		;
		this.toogleOn = this.propertyservice.getPropertyValue(propertyKey);
	}
	else
	{
		this.toogleOn = false
	}
 }
 ToggleManagerStatic.prototype.setScreenBroker = function(broker)
 {
	;
	this.broker = broker;
 }
 ToggleManagerStatic.prototype.registerToggleBroker = function(toggleBroker)
 {
	;
	this.toggleBroker = toggleBroker;
 }
 ToggleManagerStatic.prototype.start = function()
 {
	 ;
	 if (this.toggleBroker)
	 {
		if (this.toogleOn)
		{
			this.toggleBroker.doIsToggleOn();
		}
		else
		{
			this.toggleBroker.doIsToggleOff();
		}
	 }
 }
 ToggleManagerStatic.prototype.getToggleOnAction = function()
 {
	return new ObjectMethodAction(this, 'setToggleOn');
 }
 ToggleManagerStatic.prototype.getToggleOffAction = function()
 {
	return new ObjectMethodAction(this, 'setToggleOff');
 }
 ToggleManagerStatic.prototype.setToggleOn = function()
 {
	if (this.propertyservice)
		this.propertyservice.setPropertyValue(this.propertyKey, true);
	this.broker.getReloadAction().invoke();
 }
 ToggleManagerStatic.prototype.setToggleOff = function()
 {
	if (this.propertyservice)
		this.propertyservice.setPropertyValue(this.propertyKey, false);
	this.broker.getReloadAction().invoke();
 }
 ToggleManagerStatic.prototype.initService = function()
 {
 	var serviceregistry = ServiceRegistryAccess.getServiceRegistry();
 	if (serviceregistry)
   		this.propertyservice = serviceregistry.getService("propertyservice");
 }

/* toolkit/toggle/ToggleBroker.js */
 /*
 <DEPENDENCIES>
	 <DEPENDS>Logger</DEPENDS>
	 <DEPENDS>Actions</DEPENDS>
	 <DEPENDS>Broker</DEPENDS>
 </DEPENDENCIES>
 */
 ToggleBroker.prototype             = new Broker();
 ToggleBroker.prototype.constructor = ToggleBroker;
 ToggleBroker.superclass            = Broker.prototype;
 function ToggleBroker()
 {
	 ToggleBroker.superclass.init.call(this, 'ToggleBroker');
 }
 ToggleBroker.prototype.setToggleManager = function(togglemanager)
 {
	 this.togglemanager = togglemanager;
 }
 ToggleBroker.prototype.getId = function()
 {
	 return 'ToggleBroker';
 }
 ToggleBroker.prototype.doIsToggleOn = function()
 {
	 ;
	 this.getMessage('istoggleon');
 }
 ToggleBroker.prototype.addIsToggleOnHandle = function(action)
 {
	 ;
	 this.registerAction('istoggleon', action);
 }
 ToggleBroker.prototype.getToggleOnAction = function()
 {
	 ;
	 return new ObjectMethodAction(this, 'toggleOn');
 }
 ToggleBroker.prototype.toggleOn = function()
 {
	 ;
	 this.togglemanager.setToggleOn();
 }
 ToggleBroker.prototype.doIsToggleOff = function()
 {
	 ;
	 this.getMessage('istoggleoff');
 }
 ToggleBroker.prototype.addIsToggleOffHandle = function(action)
 {
	 ;
	 this.registerAction('istoggleoff', action);
 }
 ToggleBroker.prototype.getToggleOffAction = function()
 {
	 ;
	 return new ObjectMethodAction(this, 'toggleOff');
 }
 ToggleBroker.prototype.toggleOff = function()
 {
	 ;
	 this.togglemanager.setToggleOff();
 }

/* domapi/ServerResult.js */
/*
<DEPENDENCIES>
    <DEPENDS>Logger</DEPENDS>
</DEPENDENCIES>
*/
function ServerResult( sId, xmldoc )
{
  if( sId )
  {
    this.init(sId, xmldoc)
  }
}
ServerResult.prototype.init = function( sId, xmldoc )
{
  ;
  this.sId = sId;
  this.resultMap = new Array();
  ;
  this.buildMap(xmldoc);
}
ServerResult.prototype.buildMap = function( xmldoc )
{
  ;
  if( xmldoc.nodeType == Browser.Node.DOCUMENT_NODE )
  {
    ;
    for( var i = 0; i < xmldoc.childNodes.length; i++ )
    {
      ;
      if( xmldoc.childNodes[i]
              && xmldoc.childNodes[i].nodeType == Browser.Node.ELEMENT_NODE
              && xmldoc.childNodes[i].nodeName == 'results' )
      {
        ;
        var entrylist = xmldoc.getElementsByTagName('entry');
        ;
        for( var j = 0; j < entrylist.length; j++ )
        {
          var entryElement = entrylist[j];
          ;
          this.resultMap[entryElement.getAttribute('key')] = entryElement.getAttribute('value');
        }
        break;
      }
      else
      {
        ;
      }
    }
  }
}
ServerResult.prototype.getValues = function()
{
  return this.resultMap;
}

/* domapi/Browser.js */
/*
<DEPENDENCIES>
    <DEPENDS>Broker</DEPENDS>
    <DEPENDS>Logger</DEPENDS>
    <DEPENDS>ServerResult</DEPENDS>
</DEPENDENCIES>
*/
function BrowserImpl(sId)
{
	if (sId)
	{
		this.init(sId)
	}
	;
}
BrowserImpl.prototype.init = function(sId)
{
	;
	this.sId = sId;
	this.nSetToplevelCnt = 2007;
	this.eventNames = new EventNames();
	this.Node = new NodeTypes();
	this.aEventListeners = new Array();
	this.nCoverElement = 0;
	this.aUnloadHandles = new Array();
	this.orphanageNode = null;
	this.loadingImages = new Array();
	var me = this;
	this.unloadCallback = function()
	{
		me.unloadHandler();
	}
	window.BrowserOnUnload = this.unloadCallback;
}
BrowserImpl.prototype.getId = function()
{
	;
	return this.sId;
}
BrowserImpl.prototype.getCharacterSet = function()
{
	;
	if (document.characterSet)
		return document.characterSet;
	else if (document.charset)
		return document.charset;
	else
	{
		;
		return undefined;
	}
}
BrowserImpl.prototype.getBodyScrollTop = function()
{
	;
	return document.body.scrollTop;
}
BrowserImpl.prototype.getBodyScrollLeft = function()
{
	;
	return document.body.scrollLeft;
}
BrowserImpl.prototype.unloadHandler = function()
{
	for (var i = 0; i < this.aEventListeners.length; i++)
	{
		this.aEventListeners[i].domNode.removeEventListener(
				this.aEventListeners[i].eventType,
				this.aEventListeners[i].handler,
				true
				);
	}
	for (var i = 0; i < this.aUnloadHandles.length; i++)
	{
		this.aUnloadHandles[i].invoke();
	}
}
BrowserImpl.prototype.addUnloadHandle = function(unloadHandle)
{
	this.aUnloadHandles.push(unloadHandle);
}
BrowserImpl.prototype.unloadCallback = function()
{
	Browser.unloadHandler();
}
BrowserImpl.prototype.addEventListener = function(domId, eventType, handler)
{
	;
	var element = this.getElementById(domId);
	this.addEventListenerToDomNode(element, eventType, handler);
}
BrowserImpl.prototype.addEventListenerToDomNode = function(domNode, eventType, handler)
{
	;
	this.aEventListeners.push({ domNode: domNode,
		eventType: eventType,
		handler: handler
	}
			);
	domNode.addEventListener(eventType, handler, true);
}
BrowserImpl.prototype.addEventListenerToDocument = function(eventType, handler)
{
	;
	this.addEventListenerToDomNode(document, eventType, handler);
}
BrowserImpl.prototype.removeEventListener = function(domId, eventType, handler)
{
	;
	var element = this.getElementById(domId);
	this.removeEventListenerFromDomNode(element, eventType, handler);
}
BrowserImpl.prototype.removeEventListenerFromDomNode = function(domNode, eventType, handler)
{
	;
	domNode.removeEventListener(eventType, handler, true);
}
BrowserImpl.prototype.removeEventListenerFromDocument = function(eventType, handler)
{
	;
	this.removeEventListenerFromDomNode(document, eventType, handler);
}
BrowserImpl.prototype.getElementById = function(domId)
{
	//;
	var elem = document.getElementById(domId);
	if (! elem)
	{
		;
	}
	return elem;
}
BrowserImpl.prototype.changeStyleById = function(domId, styleName, styleValue)
{
	//;
	var elem = this.getElementById(domId);
	if (elem)
	{
		elem.style[styleName] = styleValue;
	}
}
BrowserImpl.prototype.changeStyleClassById = function(domId, styleClass)
{
	var elem = this.getElementById(domId);
	if (elem)
	{
		elem.className = styleClass;
	}
}
BrowserImpl.prototype.getStyleById = function(domId, styleName)
{
	//;
	var elem = this.getElementById(domId);
	var style = '';
	if (elem)
	{
		style = elem.style[styleName];
	}
	return style;
}
BrowserImpl.prototype.getComputedStyleById = function(domId, styleName)
{
	var elem = this.getElementById(domId);
	return this.getComputedStyle(elem, styleName);
}
BrowserImpl.prototype.getComputedStyle = function(node, styleName)
{
	//;
	var style = '';
	if (node)
	{
		style = window.getComputedStyle(node, null)[styleName];
	}
	return style;
}
BrowserImpl.prototype.getPixelComputedStyleById = function(domId, styleName)
{
	var elem = this.getElementById(domId);
	return this.getPixelComputedStyle(elem, styleName);
}
BrowserImpl.prototype.getPixelComputedStyle = function(node, styleName)
{
	var style = this.getComputedStyle(node, styleName);
	var iValue = parseInt(style);
	if (isNaN(iValue))
	{
		return 0;
	}
	else
	{
		return iValue;
	}
}
BrowserImpl.prototype.getPixelStyleById = function(domId, styleName)
{
	var elem = this.getElementById(domId);
	return this.getPixelStyle(elem, styleName);
}
BrowserImpl.prototype.getPixelStyle = function(node, styleName)
{
	var style = '';
	if (node)
	{
		style = node.style[styleName];
		var iValue = parseInt(style);
		if (isNaN(iValue))
		{
			return 0;
		}
		else
		{
			return iValue;
		}
	}
	else
	{
		return 0;
	}
}
BrowserImpl.prototype.changePixelStyleById = function(domId, styleName, iValue)
{
	var elem = this.getElementById(domId);
	return this.changePixelStyle(elem, styleName, iValue);
}
BrowserImpl.prototype.changePixelStyle = function(node, styleName, iValue)
{
	if (node)
	{
		node.style[styleName] = parseInt(iValue) + 'px';
	}
}
BrowserImpl.prototype.setImageSourceById = function(domId, srcURL)
{
	var elem = this.getElementById(domId);
	if (elem)
	{
		if (elem.complete != true && elem.src != "")
		{
			this.loadingImages[domId] = srcURL;
			window.setTimeout('Browser.checkLoadingImages()', 300);
		}
		else
		{
			elem.src = srcURL;
		}
	}
}
BrowserImpl.prototype.checkLoadingImages = function()
{
	var c = 0;
	for (domId in this.loadingImages)
	{
		var elem = this.getElementById(domId);
		if (elem)
		{
			if (elem.complete == false && elem.src != "")
			{
				c++;
			}
			else
			{
				elem.src = this.loadingImages[domId];
			}
		}
	}
	if (c > 0)
	{
		window.setTimeout('Browser.checkLoadingImages()', 300);
	}
}
BrowserImpl.prototype.setImageWidthById = function(domId, width)
{
	//;
	var elem = this.getElementById(domId);
	if (elem)
	{
		elem.width = width;
	}
}
BrowserImpl.prototype.eventStopPropagation = function(event)
{
	event.stopPropagation();
}
BrowserImpl.prototype.eventPreventDefault = function(event)
{
	event.preventDefault();
}
BrowserImpl.prototype.getKeyCodeFromEvent = function(event)
{
	//;
	return event.which;
}
BrowserImpl.prototype.getOriginalTargetFromEvent = function(event)
{
	//;
	return event.originalTarget;
}
BrowserImpl.prototype.getAbsPos = function(domNode, point)
{
	//;
	point.x += domNode.offsetLeft;
	point.y += domNode.offsetTop;
	if (domNode.offsetParent != null)
	{
		if (domNode.offsetParent.tagName != 'BODY')
		{
			this.getAbsPos(domNode.offsetParent, point);
		}
	}
}
BrowserImpl.prototype.getAbsPosHtml = function(domNode, point)
{
	//;
	point.x += domNode.offsetLeft;
	point.y += domNode.offsetTop;
	if (domNode.offsetParent != null)
	{
		if (domNode.offsetParent.tagName != 'HTML')
		{
			this.getAbsPosHtml(domNode.offsetParent, point);
		}
	}
}
BrowserImpl.prototype.getScrollPos = function(domNode, point)
{
	//;
	point.x += domNode.scrollLeft;
	point.y += domNode.scrollTop;
	//;
	if (domNode.offsetParent != null)
	{
		if (domNode.nodeName != 'HTML')
		{
			this.getScrollPos(domNode.offsetParent, point);
		}
	}
	else
	{
		point.x += pageXOffset;
		point.y += pageYOffset;
	}
}
BrowserImpl.prototype.getScreenPos = function(domNode, point)
{
	//;
	point.x += domNode.offsetLeft - domNode.scrollLeft;
	point.y += domNode.offsetTop - domNode.scrollTop;
	if (domNode.offsetParent != null)
	{
		if (domNode.offsetParent.tagName != 'BODY')
		{
			this.getScreenPos(domNode.offsetParent, point);
		}
	}
}
BrowserImpl.prototype.getParentLocation = function(domNode, point)
{
	//;
	domNode = domNode.offsetParent;
	if (domNode != null)
	{
		if (domNode.tagName != 'BODY')
		{
			point.x += domNode.offsetLeft + this.getPixelComputedStyle(domNode, "borderLeftWidth");
			point.y += domNode.offsetTop + this.getPixelComputedStyle(domNode, "borderTopWidth");
			this.getParentLocation(domNode, point);
		}
	}
}
BrowserImpl.prototype.getLocation = function(domNode, point)
{
	//;
	point.x += domNode.offsetLeft;
	point.y += domNode.offsetTop;
	this.getParentLocation(domNode, point);
}
BrowserImpl.prototype.getChildById = function(domNode, sId)
{
	//;
	var childNode = null;
	for (i in domNode.childNodes)
	{
		if (domNode.childNodes[i].id == sId)
		{
			childNode = domNode.childNodes[i];
			break;
		}
	}
	return childNode;
}
BrowserImpl.prototype.moveTo = function(domNode, point)
{
	//;
	domNode.style.position = 'absolute';
	var parentPos = new Point(0, 0);
	if (domNode.offsetParent)
	{
		this.getAbsPos(domNode.offsetParent, parentPos);
	}
	domNode.style.left = (point.x - parentPos.x) + 'px';
	domNode.style.top = (point.y - parentPos.y) + 'px';
}
BrowserImpl.prototype.moveToLocation = function(domNode, point)
{
	//;
	domNode.style.position = 'absolute';
	var parentPos = new Point(0, 0);
	this.getLocation(domNode, parentPos);
	domNode.style.left = (point.x - parentPos.x) + 'px';
	domNode.style.top = (point.y - parentPos.y) + 'px';
}
BrowserImpl.prototype.getKeyCodeFromEvent = function(event)
{
	//;
	return event.which;
}
BrowserImpl.prototype.setToplevel = function(domNode)
{
	;
	
	
	this.nSetToplevelCnt += 10;
	domNode.style.zIndex = this.nSetToplevelCnt;
}
BrowserImpl.prototype.loadDocument = function(url, onLoadAction, onErrorAction)
{
	var xmldoc = document.implementation.createDocument("", "", null);
	var onloadHandler = function()
	{
		if (onLoadAction)
			onLoadAction.invoke(xmldoc);
		Broker.actionPipeline.unblock(url);
	};
	var onabortHandler = function()
	{
		if (onErrorAction)
			onErrorAction.invoke();
		Broker.actionPipeline.unblock(url);
	};
	var onerrorHandler = function()
	{
		if (onErrorAction)
			onErrorAction.invoke();
		Broker.actionPipeline.unblock(url);
	};
	xmldoc.addEventListener("load", onloadHandler, true);
	xmldoc.addEventListener("error", onerrorHandler, true);
	xmldoc.addEventListener("abort", onabortHandler, true);
	Broker.actionPipeline.block(url);
	xmldoc.load(url);
}
BrowserImpl.prototype.loadXMLDocument = function(url, onLoadAction, onErrorAction)
{
	var request = new XMLHttpRequest();
	var onloadHandler = function()
	{
		if (request.readyState == 4)
		{
			if (request.status == 200)
			{
				if (onLoadAction)
					onLoadAction.invoke(request.responseXML);
			}
			else
			{
				if (onErrorAction)
					onErrorAction.invoke("Errors retrieveing XML for url " + url + ". Message is: " + request.statusText);
			}
			Broker.actionPipeline.unblock(url);
		}
	};
	Broker.actionPipeline.block(url);
	request.onreadystatechange = onloadHandler;
	request.open("GET", url, true);
	request.send("");
}
BrowserImpl.prototype.loadXMLDocumentPost = function(url, args, onLoadAction, onErrorAction)
{
	var request = new XMLHttpRequest();
	var onloadHandler = function()
	{
		if (request.readyState == 4)
		{
			if (request.status == 200)
			{
				if (onLoadAction)
					onLoadAction.invoke(request.responseXML);
			}
			else
			{
				if (onErrorAction)
					onErrorAction.invoke("Errors retrieveing XML for url " + url + ". Message is: " + request.statusText);
			}
			Broker.actionPipeline.unblock(url);
		}
	};
	Broker.actionPipeline.block(url);
	request.onreadystatechange = onloadHandler;
	request.open("POST", url, true);
	request.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
	request.send(args);
}
BrowserImpl.prototype.callURL = function(url, onLoadAction, onErrorAction)
{
	var xmldoc = document.implementation.createDocument("", "", null);
	var onloadHandler = function()
	{
		if (onLoadAction)
			onLoadAction.invoke();
		Broker.actionPipeline.unblock(url);
	};
	var onabortHandler = function()
	{
		if (onErrorAction)
			onErrorAction.invoke();
		Broker.actionPipeline.unblock(url);
	};
	var onerrorHandler = function()
	{
		if (onErrorAction)
			onErrorAction.invoke();
		Broker.actionPipeline.unblock(url);
	};
	xmldoc.addEventListener("load", onloadHandler, true);
	xmldoc.addEventListener("error", onerrorHandler, true);
	xmldoc.addEventListener("abort", onabortHandler, true);
	Broker.actionPipeline.block(url);
	xmldoc.load(url);
}
BrowserImpl.prototype.callServer = function(url, onLoadAction, onErrorAction)
{
	var xmldoc = document.implementation.createDocument("", "", null);
	var onloadHandler = function()
	{
		if (onLoadAction)
		{
			var result = new ServerResult(this.sId + '_result', xmldoc);
			onLoadAction.invoke(result.getValues());
		}
		Broker.actionPipeline.unblock(url);
	};
	var onabortHandler = function()
	{
		if (onErrorAction)
			onErrorAction.invoke();
		Broker.actionPipeline.unblock(url);
	};
	var onerrorHandler = function()
	{
		if (onErrorAction)
			onErrorAction.invoke();
		Broker.actionPipeline.unblock(url);
	};
	xmldoc.addEventListener("load", onloadHandler, true);
	xmldoc.addEventListener("error", onerrorHandler, true);
	xmldoc.addEventListener("abort", onabortHandler, true);
	Broker.actionPipeline.block(url);
	xmldoc.load(url);
}
BrowserImpl.prototype.getCoverElement = function(elem)
{
	this.nCoverElement++;
	var oCoverElem = document.createElement("DIV");
	oCoverElem.id = 'Browser_sCoverWidgetDomId_' + this.nCoverElement;
	if (elem && elem.style)
	{
		var zindex = this.getComputedStyle(elem, 'zIndex');
		if (zindex == 'auto')
		{
			this.setToplevel(oCoverElem);
		}
		else
		{
			oCoverElem.style.zIndex = parseInt(zindex) + 1;
		}
	}
	return oCoverElem;
}
BrowserImpl.prototype.replaceRelative = function(url)
{
	document.location.href = url;
}
BrowserImpl.prototype.replaceRelative = function(url)
{
	document.location.href = this.getRelativeURL(url);
}
BrowserImpl.prototype.getRelativeURL = function(url)
{
	return url;
}
BrowserImpl.prototype.getBaseURL = function()
{
	return window.document.baseURI;
}
BrowserImpl.prototype.getEventSourceElement = function(event)
{
	return event.explicitOriginalTarget;
}
BrowserImpl.prototype.removeNodeFromParent = function(node)
{
	if (this.orphanageNode == null)
	{
		var bodyNodes = document.getElementsByTagName('body');
		if (bodyNodes.length > 0)
		{
			var bodyNode = bodyNodes[0];
			this.orphanageNode = document.createElement('div');
			this.orphanageNode.id = 'node_orphanage_' + new Date().getTime();
			this.orphanageNode.style.display = 'none';
			bodyNode.appendChild(this.orphanageNode);
		}
	}
	if (this.orphanageNode != null)
	{
		this.orphanageNode.appendChild(node);
	}
}
function EventNames()
{
	this.LOAD = 'load';
	this.UNLOAD = 'unload';
	this.CLICK = 'click';
	this.DOUBLECLICK = 'dblclick';
	this.DRAGDROP = 'dragdrop';
	this.CHANGE = 'change';
	this.MOUSEDOWN = 'mousedown';
	this.MOUSEUP = 'mouseup';
	this.MOUSEOVER = 'mouseover';
	this.MOUSEOUT = 'mouseout';
	this.MOUSEMOVE = 'mousemove';
	this.SELECT = 'select';
	this.BLUR = 'blur';
	this.FOCUS = 'focus';
	this.KEYPRESS = 'keypress';
	this.KEYUP = 'keyup';
	this.KEYDOWN = 'keydown';
	this.DRAGSTART = '';
	this.MOUSEWHEEL = 'DOMMouseScroll';
}
function NodeTypes()
{
	this.ELEMENT_NODE = Node.ELEMENT_NODE;
	this.ATTRIBUTE_NODE = Node.ATTRIBUTE_NODE;
	this.TEXT_NODE = Node.TEXT_NODE;
	this.CDATA_SECTION_NODE = Node.CDATA_SECTION_NODE;
	this.ENTITY_REFERENCE_NODE = Node.ENTITY_REFERENCE_NODE;
	this.ENTITY_NODE = Node.ENTITY_NODE;
	this.PROCESSING_INSTRUCTION_NODE = Node.PROCESSING_INSTRUCTION_NODE;
	this.COMMENT_NODE = Node.COMMENT_NODE;
	this.DOCUMENT_NODE = Node.DOCUMENT_NODE;
	this.DOCUMENT_TYPE_NODE = Node.DOCUMENT_TYPE_NODE;
	this.DOCUMENT_FRAGMENT_NODE = Node.DOCUMENT_FRAGMENT_NODE;
	this.NOTATION_NODE = Node.NOTATION_NODE;
}
Browser = new BrowserImpl('moz');

/* toolkit/screen/ScreenController.js */
/*
<DEPENDENCIES>
    <DEPENDS>Logger</DEPENDS>
    <DEPENDS>Actions</DEPENDS>
    <DEPENDS>Browser</DEPENDS>
    <DEPENDS>FinalObjectMethodAction</DEPENDS>
</DEPENDENCIES>
*/
function ScreenController(sId, contentId, popupAllowed, popup)
{
    this.init(sId, contentId, popupAllowed, popup)
}
ScreenController.prototype.init = function(sId, contentId, popupAllowed, popup)
{
  ;
  this.sId = sId;
  this.contentId = contentId;
  this.screenBroker = null;
  this.popupAllowed = popupAllowed;
  this.popup = popup;
  this.openerFrame = false;
}
ScreenController.prototype.start = function()
{
  ;
  if(this.popup)
    this.startPopupAware();
  if(this.screenBroker)
  {
    Browser.addUnloadHandle(new ObjectMethodAction(this.screenBroker, 'doUnload'));
    this.screenBroker.addReplaceHandle(new FinalObjectMethodAction(this, "doTheReplace"));
    this.screenBroker.addReloadHandle(new FinalObjectMethodAction(this, "doTheReload"));
    this.screenBroker.addLogoutHandle(new FinalObjectMethodAction(this, "doTheLogout"));
  }
}
ScreenController.prototype.startPopupAware = function()
{
  if (opener)
  {
    if (opener.top.frames.length > 1)
    {
      this.openerFrame = true;
    }
  }
  if (opener && !this.openerFrame)
  {
      if (opener.screenBroker)
      {
        opener.screenBroker.notifyPopupAware(this.screenBroker);
      }
  }
  else
  {
    if (opener)
    {
      if (this.openerFrame && opener.top.frames.length < 2)
      {
	    if (Browser.getId() == 'moz')
	    {
	      top.close();
	    }
	    else
	    {
	      self.close();
	    }
      }
      else if (opener.screenBroker)
      {
        opener.screenBroker.notifyPopupAware(this.screenBroker);
      }
    }
    else if (this.openerFrame)
    {
      if (Browser.getId() == 'moz')
      {
        top.close();
      }
      else
      {
        self.close();
      }
    }
  }
  var thisScreenController = this;
  var callback = function()
  {
     thisScreenController.startPopupAware();
  };
  window.setTimeout(callback, 1000);
}
if (openedWindows == undefined) {
    ;
    var openedWindows = new Object();
}
ScreenController.prototype.register = function(screenBroker)
{
    this.screenBroker = screenBroker;
    this.screenBroker.setScreenController(this);
}
ScreenController.prototype.shouldReplace = function(extURL)
{
  this.screenBroker.doLeave();
  this.screenBroker.doReplace(extURL);
}
ScreenController.prototype.shouldReload = function()
{
  this.screenBroker.doLeave();
  this.screenBroker.doReload();
}
ScreenController.prototype.shouldPopup = function(extURL, windowName, width, height, scrollbars, resizable)
{
    this.doThePopup(extURL, windowName, width, height, scrollbars, resizable);
}
ScreenController.prototype.shouldIFrame = function(extURL, windowName)
{
    this.doTheIFrame(extURL, windowName);
}
ScreenController.prototype.shouldInvokeServletMethod = function(extURL, successAction, errorAction)
{
    this.doTheInvokeServletMethod(extURL, successAction, errorAction);
}
ScreenController.prototype.shouldCallServer = function(extURL, successAction, errorAction)
{
    this.doTheCallServer(extURL, successAction, errorAction);
}
ScreenController.prototype.shouldClosePopup = function(windowName)
{
    this.doTheClosePopup(windowName);
}
ScreenController.prototype.shouldReloadPopup = function(extURL, windowName)
{
    this.doTheReloadPopup(extURL, windowName);
}
ScreenController.prototype.doTheReplace = function(extURL)
{
  ;
  try
  {
    window.location.href = extURL;
  }
  catch(exeption)
  {
  }
}
ScreenController.prototype.doTheReload = function()
{
  ;
  this.screenBroker.doLeave();
  window.location.reload();
}
ScreenController.prototype.doTheReloadPopup = function(extURL, windowName)
{
    var wind = window.open('', windowName);
    if(wind)
        wind.location.href = extURL;
    openedWindows[windowName] = wind;
}
ScreenController.prototype.doThePopup = function(extURL, windowName, width, height, scrollbars, resizable)
{
  ;
  if (extURL == null) extURL = "/error";
  if (width == null) width = 850;
  if (height == null) height = 650;
  if (windowName == null) windowName = 'scola-af' + new Date().getTime();
  windowName = windowName.replace (/\W/g, "");
  var wind = window.open('', windowName, 'width=' + width + ', height=' + height + ', menubar=no, scrollbars=' + scrollbars + ', toolbar=no, status=no, resizable=' + resizable);
  if (wind)
  {
    wind.location.href = extURL;
  	wind.focus();
  }
  ;
  openedWindows[windowName] = wind;
}
ScreenController.prototype.doTheIFrame = function(extURL, windowName)
{
  ;
  if (extURL == null) extURL = "/error";
  var width = 350;
  var height = 200;
  if (windowName == null) windowName = 'scola-af' + new Date().getTime();
  var wind = window.open('', windowName, 'width=' + width + ', height=' + height + ', menubar=no, scrollbars=no, toolbar=no, status=no, resizable=no');
  if(wind)
    wind.location.href = extURL;
}
ScreenController.prototype.doTheInvokeServletMethod = function(extURL, successAction, errorAction)
{
  ;
  Browser.callURL(extURL, successAction, errorAction);
}
ScreenController.prototype.doTheCallServer = function(extURL, successAction, errorAction)
{
  ;
  Browser.callServer(extURL, successAction, errorAction);
}
ScreenController.prototype.doTheClosePopup = function(windowName)
{
  ;
  ;
  if(openedWindows[windowName])
  {
    ;
    openedWindows[windowName].close();
  }
  else 
  {
    ;
    top.close();
  }
}
ScreenController.prototype.doNotifyPopupAware = function(screenBroker)
{
  ;
  if (!this.popupAllowed)
    screenBroker.closePopup(null);
}
ScreenController.prototype.shouldNotifyPopupAware = function(screenBroker)
{
    this.doNotifyPopupAware(screenBroker);
}
ScreenController.prototype.shouldLoaded = function()
{
    this.screenBroker.doLoaded();
}
ScreenController.prototype.shouldUnload = function()
{
    this.screenBroker.doUnload();
}
ScreenController.prototype.shouldOpenWindow = function(url, target)
{
    this.doTheOpenWindow(url, target);
}
ScreenController.prototype.doTheOpenWindow = function(url, target)
{
  if (target == null) target = '_blank';
  var wind = window.open('', target);
  if (wind)
  {
    wind.location.href = url;
  	wind.focus();
  }
}
ScreenController.prototype.shouldOpenerReplace = function(internalURL)
{
    this.doTheOpenerReplace(internalURL);
}
ScreenController.prototype.doTheOpenerReplace = function(internalURL)
{
    opener.location.href = internalURL;
}
ScreenController.prototype.shouldAddUserMarker = function(markerId)
{
    if (this.screenBroker.bookmarkable)
        this.doAddUserMarker(markerId);
}
ScreenController.prototype.shouldLogout = function()
{
  this.screenBroker.doLeave();
  this.screenBroker.doLogout();
}
ScreenController.prototype.doTheLogout = function()
{
  Browser.replaceRelative("../credits");
}
ScreenController.prototype.doAddUserMarker = function(markerId)
{
    this.doTheInvokeServletMethod("../multimarker?ACTION=add&MARKER_TYPE=user&MARKER_ID=" + encodeURIComponent(markerId) +
                        "&CONTENT=" + encodeURIComponent(this.contentId));
    this.screenBroker.doAddUserMarker(markerId);
}

/* toolkit/pager/VisibilityBroker.js */
/*
<DEPENDENCIES>
    <DEPENDS>Logger</DEPENDS>
    <DEPENDS>Actions</DEPENDS>
    <DEPENDS>Broker</DEPENDS>
</DEPENDENCIES>
*/
VisibilityBroker.prototype             = new Broker();
VisibilityBroker.prototype.constructor = VisibilityBroker;
VisibilityBroker.superclass            = Broker.prototype;
function VisibilityBroker(sId)
{
  if (sId) { this.init(sId); }
}
VisibilityBroker.prototype.init = function(sId)
{
  ;
  this.sId = sId;
  this.visibilityController = null;
  VisibilityBroker.superclass.init.call(this, sId);
}
VisibilityBroker.prototype.setPagingController = function(visibilityController)
{
  this.visibilityController = visibilityController;
}
VisibilityBroker.prototype.doActivity = function()
{
  this.getMessage('activity');
}
VisibilityBroker.prototype.addActivityHandle = function(action)
{
  this.registerAction('activity', action);
}
VisibilityBroker.prototype.getActivityAction = function(action)
{
  return new ObjectMethodAction(this, 'activity');
}
VisibilityBroker.prototype.activity = function()
{
  ;
  if (this.visibilityController)
    this.visibilityController.shouldActivity();
  else
    this.doActivity();
}
VisibilityBroker.prototype.doShow = function()
{
  this.getMessage('show');
}
VisibilityBroker.prototype.addShowHandle = function(action)
{
  this.registerAction('show', action);
}
VisibilityBroker.prototype.getShowAction = function(action)
{
  return new ObjectMethodAction(this, 'show');
}
VisibilityBroker.prototype.show = function()
{
  ;
  if (this.visibilityController)
    this.visibilityController.shouldShow();
  else
    this.doShow();
}
VisibilityBroker.prototype.doHide = function()
{
  this.getMessage('hide');
}
VisibilityBroker.prototype.addHideHandle = function(action)
{
  this.registerAction('hide', action);
}
VisibilityBroker.prototype.getHideAction = function(action)
{
  return new ObjectMethodAction(this, 'hide');
}
VisibilityBroker.prototype.hide = function()
{
  ;
  if (this.visibilityController)
    this.visibilityController.shouldHide();
  else
    this.doHide();
}
VisibilityBroker.prototype.doEvaluatesWrong = function()
{
  this.getMessage('evaluatesWrong');
}
VisibilityBroker.prototype.addEvaluatesWrongHandle = function(action)
{
  this.registerAction('evaluatesWrong', action);
}
VisibilityBroker.prototype.getEvaluatesWrongAction = function(action)
{
  return new ObjectMethodAction(this, 'evaluatesWrong');
}
VisibilityBroker.prototype.evaluatesWrong = function()
{
  ;
  if (this.visibilityController)
    this.visibilityController.shouldEvaluatesWrong();
  else
    this.doEvaluatesWrong();
}

/* toolkit/info/InformationVisibilityManager.js */
/*
<DEPENDENCIES>
    <DEPENDS>Logger</DEPENDS>
    <DEPENDS>VisibilityBroker</DEPENDS>
</DEPENDENCIES>
*/
function InformationVisibilityManager(sId)
{
  if (sId) { this.init(sId); }
}
InformationVisibilityManager.prototype.init = function(sId)
{
  this.sId = sId;
  this.nBrokers = 0;
  this.brokers = new Array();
  this.registeredInformation = new Array();
}
InformationVisibilityManager.prototype.getShowAction = function(usage)
{
  return this.findBroker(usage).getShowAction();
}
InformationVisibilityManager.prototype.registerShowHandle = function(usage, handle)
{
  this.findBroker(usage).addShowHandle(handle);
}
InformationVisibilityManager.prototype.registerInformationVisibility = function(usage, visibilityBroker)
{
  this.findBroker(usage).addShowHandle(visibilityBroker.getShowAction());
  this.findBroker(usage).addHideHandle(visibilityBroker.getHideAction());
  this.registeredInformation[usage] = true;
}
InformationVisibilityManager.prototype.getHideAction = function(usage)
{
  return this.findBroker(usage).getHideAction();
}
InformationVisibilityManager.prototype.registerHideHandle = function(usage, handle)
{
  this.findBroker(usage).addHideHandle(handle);
}
InformationVisibilityManager.prototype.getActivateAction = function(usage)
{
  return this.findBroker(usage).getActivityAction();
}
InformationVisibilityManager.prototype.registerActivateHandle = function(usage, handle)
{
  this.findBroker(usage).addActivityHandle(handle);
}
InformationVisibilityManager.prototype.findBroker = function(usage)
{
  var broker;
  if(this.brokers[usage])
  {
    broker = this.brokers[usage];
  }
  else
  {
    broker = new VisibilityBroker(this.createBrokerName());
    this.brokers[usage] = broker;
  }
  return broker;
}
InformationVisibilityManager.prototype.activateAll = function()
{
  for(var usage in this.registeredInformation)
  {
    if(this.registeredInformation[usage])
    {
      this.findBroker(usage).activity();
    }
  }
}
InformationVisibilityManager.prototype.createBrokerName = function()
{
  this.nBrokers++;
  return 'infoVisibilityBroker_' + this.nBrokers;
}
InformationVisibilityManager.prototype.start = function()
{
  this.activateAll();
}

/* toolkit/staticexport/ScoreStatistics.js */
/*
<DEPENDENCIES>
    <DEPENDS>Logger</DEPENDS>
</DEPENDENCIES>
*/
function ScoreStatistics(fractionCorrect, fractionCorrectWithHelp, fractionWrong, fractionDone, fractionUndone) {
  	;
  	this.fractionCorrect = fractionCorrect;
  	this.fractionCorrectWithHelp = fractionCorrectWithHelp;
  	this.fractionWrong = fractionWrong;
  	this.fractionDone = fractionDone;
  	this.fractionUndone = fractionUndone;
}
ScoreStatistics.prototype.getFractionCorrect= function() {
	;
	return this.fractionCorrect;
}
ScoreStatistics.prototype.getFractionCorrectWithHelp= function() {
	;
	return this.fractionCorrectWithHelp;
}
ScoreStatistics.prototype.getFractionWrong= function() {
	;
	return this.fractionWrong;
}
ScoreStatistics.prototype.getFractionDone= function() {
	;
	return this.fractionDone;
}
ScoreStatistics.prototype.getFractionUndone= function() {
	;
	return this.fractionUndone;
}

/* toolkit/achievement/AchievementStatistic.js */
/*
 <DEPENDENCIES>
	 <DEPENDS>Browser</DEPENDS>
	 <DEPENDS>Logger</DEPENDS>
	 <DEPENDS>ServiceRegistryAccessor</DEPENDS>
 </DEPENDENCIES>
 */
function AchievementStatistic(structureName, contentidentifier, trace, scorestatistics)
{
	if (scorestatistics != undefined)
	{
   		this.scorestatistics = scorestatistics;
	}
	else
	{
		this.scorestatistics = null;
		this.trace = trace;
		this.init(structureName, contentidentifier);
	}
}
AchievementStatistic.prototype.init = function(structureName, contentidentifier)
{
	;
	var achievementservice = null;
	var serviceregistry = ServiceRegistryAccess.getServiceRegistry();
	if (serviceregistry)
		achievementservice = serviceregistry.getService("achievementservice");
	if (achievementservice)
	{
		if (this.trace)
			this.scorestatistics = achievementservice.getScoreStatisticsTrace(structureName, contentidentifier);
		else
			this.scorestatistics = achievementservice.getScoreStatisticsTrack(structureName, contentidentifier);
	}
} 
AchievementStatistic.prototype.getScoreStatistics = function()
{
	return this.scorestatistics;
}
AchievementStatistic.prototype.parseFormula = function(formula)
{
	if (!this.scorestatisticsvalues)
	{
		
		;
		this.scorestatisticsvalues = new Array();
		this.scorestatisticsvalues["\\[scorestatistics.fractionCorrect\\]"] = this.scorestatistics.getFractionCorrect();
		this.scorestatisticsvalues["\\[scorestatistics.fractionCorrectWithHelp\\]"] = this.scorestatistics.getFractionCorrectWithHelp();
		this.scorestatisticsvalues["\\[scorestatistics.fractionWrong\\]"] = this.scorestatistics.getFractionWrong();
		this.scorestatisticsvalues["\\[scorestatistics.fractionDone\\]"] = this.scorestatistics.getFractionDone();
		this.scorestatisticsvalues["\\[scorestatistics.fractionUndone\\]"] = this.scorestatistics.getFractionUndone();
	}
	for (var param in this.scorestatisticsvalues)
	{
		while (formula.search(param) > -1)
		{
			formula = formula.replace(new RegExp(param), this.scorestatisticsvalues[param]);
		}
	}
	return formula;
}

/* toolkit/achievement/AchievementManager.js */
/*
<DEPENDENCIES>
    <DEPENDS>Logger</DEPENDS>
    <DEPENDS>ScoreStatistics</DEPENDS>
    <DEPENDS>AchievementStatistic</DEPENDS>
</DEPENDENCIES>
*/
function ServerResultAction(scoreStatisticsAction)
{
	this.scoreStatisticsAction = scoreStatisticsAction;
}
ServerResultAction.prototype.invoke = function(resultMap)
{
	if (resultMap && this.scoreStatisticsAction)
		this.scoreStatisticsAction.invoke(
				new ScoreStatistics(
				resultMap['fractionCorrect'],
				resultMap['fractionCorrectWithHelp'],
				resultMap['fractionWrong'],
				resultMap['fractionDone'],
				resultMap['fractionUndone']));
}
function CommitedAction(broker, otherAction)
{
	;
	this.broker = broker;
	this.otherAction = otherAction;
}
CommitedAction.prototype.invoke = function()
{
	;
	if (this.otherAction)
	{
		this.otherAction.invoke();
	}
	if (this.broker)
	{
		this.broker.commited();
	}
}
AchievementManager.prototype = new Broker();
AchievementManager.prototype.constructor = AchievementManager;
AchievementManager.superclass = Broker.prototype;
function AchievementManager()
{
	this.init('AchievementManager');
}
AchievementManager.prototype.init = function(name)
{
	this.conditionHandles = new ConditionHandleMap();
	AchievementManager.superclass.init.call(this, name);
}
AchievementManager.prototype.start = function()
{
	var initialHandles = this.conditionHandles.getInitialHandleCallbacks();
	for (var i in initialHandles)
	{
		var callback = initialHandles[i];
		this.getScoreStatisticsTrace(callback, 'lrn', callback.getContentIdentifier());
	}
}
AchievementManager.prototype.getStartTestAction = function(cid)
{
	return new ObjectMethodAction(this, 'startTest', cid);
}
AchievementManager.prototype.startTest = function(cid)
{
	
}
AchievementManager.prototype.getFinishTestAction = function(cid, callback)
{
	return new ObjectMethodAction(this, 'finishTest', cid, callback);
}
AchievementManager.prototype.finishTest = function(cid, callback)
{
	
}
AchievementManager.prototype.addCommitedHandle = function(action)
{
	this.registerAction("commited", action);
}
AchievementManager.prototype.commited = function()
{
	this.getMessage("commited");
}
AchievementManager.prototype.addTestStartedHandle = function(action)
{
	this.registerAction("teststarted", action);
}
AchievementManager.prototype.addTestFinishedHandle = function(action)
{
	this.registerAction("testfinished", action);
}
AchievementManager.prototype.addContionHandle = function(action, cid, condition, initial, permanent)
{
	this.conditionHandles.addConditionHandle(new ConditionHandle(action, cid, condition, initial, permanent));
}
AchievementManagerDynamicEnvironment.prototype = new AchievementManager();
AchievementManagerDynamicEnvironment.prototype.constructor = AchievementManagerDynamicEnvironment;
AchievementManagerDynamicEnvironment.superclass = AchievementManager.prototype;
function AchievementManagerDynamicEnvironment()
{
	this.init();
}
AchievementManagerDynamicEnvironment.prototype.init = function()
{
	AchievementManagerDynamicEnvironment.superclass.init.call(this, 'AchievementManagerDynamicEnvironment');
}
AchievementManagerDynamicEnvironment.prototype.sendTrackResultData = function(callback, identifier,
																			  nTouched, nTotal, nCorrect, nWrong, nCorrectStatus,
																			  nWrongStatus, nCorrectSystem, nWrongSystem)
{
	;
	var URL = '../addachievement?IDENTIFIER=' + encodeURIComponent(identifier);
	URL += '&TOUCHED=' + nTouched;
	URL += '&TOTAL=' + nTotal;
	URL += '&CORRECT=' + nCorrect;
	URL += '&WRONG=' + nWrong;
	URL += '&CORRECTSTATUS=' + nCorrectStatus;
	URL += '&WRONGSTATUS=' + nWrongStatus;
	URL += '&CORRECTSYSTEM=' + nCorrectSystem;
	URL += '&WRONGSYSTEM=' + nWrongSystem;
	URL += '&EVALMODE=TRACK';
	var commitedAction = new CommitedAction(this, callback);
	Browser.loadDocument(URL, commitedAction, commitedAction);
}
AchievementManagerDynamicEnvironment.prototype.sendTraceResultData = function(callback, identifier,
																			  nTouched, nTotal, nCorrect, nWrong, nCorrectStatus,
																			  nWrongStatus, nCorrectSystem, nWrongSystem)
{
	;
	var URL = '../addachievement?IDENTIFIER=' + encodeURIComponent(identifier);
	URL += '&TOUCHED=' + nTouched;
	URL += '&TOTAL=' + nTotal;
	URL += '&CORRECT=' + nCorrect;
	URL += '&WRONG=' + nWrong;
	URL += '&CORRECTSTATUS=' + nCorrectStatus;
	URL += '&WRONGSTATUS=' + nWrongStatus;
	URL += '&CORRECTSYSTEM=' + nCorrectSystem;
	URL += '&WRONGSYSTEM=' + nWrongSystem;
	URL += '&EVALMODE=TRACE';
	var commitedAction = new CommitedAction(this, callback);
	Browser.loadDocument(URL, commitedAction, commitedAction);
}
AchievementManagerDynamicEnvironment.prototype.getScoreStatisticsTrace
		= function(callback, structureName, contentidentifier)
{
	;
	var URL = '../getachievement?IDENTIFIER=' + encodeURIComponent(contentidentifier);
	URL += '&STRUCTURE=lrn';
	URL += '&EVALMODE=TRACE';
	var serverResultAction = new ServerResultAction(callback);
	Browser.callServer(URL, serverResultAction, serverResultAction);
}
AchievementManagerDynamicEnvironment.prototype.getScoreStatisticsTrack
		= function(callback, structureName, contentidentifier)
{
	;
	var URL = '../getachievement?IDENTIFIER=' + encodeURIComponent(contentidentifier);
	URL += '&STRUCTURE=lrn';
	URL += '&EVALMODE=TRACK';
	var serverResultAction = new ServerResultAction(callback);
	Browser.callServer(URL, serverResultAction, serverResultAction);
}
AchievementManagerDynamicEnvironment.prototype.startTest = function(cid)
{
	this.getMessage("teststarted");
}
AchievementManagerDynamicEnvironment.prototype.finishTest = function(callback)
{
	this.getMessage("testfinished");
}
AchievementManagerStaticEnvironment.prototype = new AchievementManager();
AchievementManagerStaticEnvironment.prototype.constructor = AchievementManagerStaticEnvironment;
AchievementManagerStaticEnvironment.superclass = AchievementManager.prototype;
function AchievementManagerStaticEnvironment()
{
	this.init();
}
AchievementManagerStaticEnvironment.prototype.init = function()
{
	this.achievementservice = null;
	AchievementManagerStaticEnvironment.superclass.init.call(this, 'AchievementManagerStaticEnvironment');
}
AchievementManagerStaticEnvironment.prototype.start = function()
{
	if (this.asname)
	{
		var serviceregistry = ServiceRegistryAccess.getServiceRegistry();
		if (serviceregistry)
			this.achievementservice = serviceregistry.getService("achievementservice");
	}
	AchievementManagerStaticEnvironment.superclass.start.call(this);
}
AchievementManagerStaticEnvironment.prototype.setAchievementServiceName = function(asname)
{
	this.asname = asname;
}
AchievementManagerStaticEnvironment.prototype.sendTrackResultData = function(callback, identifier,
																			 nTouched, nTotal, nCorrect, nWrong, nCorrectStatus,
																			 nWrongStatus, nCorrectSystem, nWrongSystem)
{
	if (this.achievementservice)
		this.achievementservice.setTrackData(identifier, nTouched, nTotal, nCorrect,
				nWrong, nCorrectStatus, nWrongStatus, nCorrectSystem, nWrongSystem);
	var commitedAction = new CommitedAction(this, callback);
	commitedAction.invoke();
}
AchievementManagerStaticEnvironment.prototype.sendTraceResultData = function(callback, identifier,
																			 nTouched, nTotal, nCorrect, nWrong, nCorrectStatus,
																			 nWrongStatus, nCorrectSystem, nWrongSystem)
{
	if (this.achievementservice)
		this.achievementservice.setTraceData(identifier, nTouched, nTotal, nCorrect,
				nWrong, nCorrectStatus, nWrongStatus, nCorrectSystem, nWrongSystem);
	var commitedAction = new CommitedAction(this, callback);
	commitedAction.invoke();
}
AchievementManagerStaticEnvironment.prototype.getScoreStatisticsTrace
		= function(callback, structureName, contentidentifier)
{
	var scorestatistics = null;
	if (this.achievementservice)
	{
		scorestatistics = this.achievementservice.getScoreStatisticsTrace(structureName, contentidentifier);
	}
	if (callback)
		callback.invoke(scorestatistics);
}
AchievementManagerStaticEnvironment.prototype.getScoreStatisticsTrack
		= function(callback, structureName, contentidentifier)
{
	;
	var scorestatistics = null;
	if (this.achievementservice)
	{
		scorestatistics = this.achievementservice.getScoreStatisticsTrack(structureName, contentidentifier);
	}
	if (callback)
		callback.invoke(scorestatistics);
}
AchievementManagerStaticEnvironment.prototype.startTest = function(cid)
{
	if (this.achievementservice)
		this.achievementservice.startTest(cid);
	this.getMessage('teststarted');
}
AchievementManagerStaticEnvironment.prototype.finishTest = function(callback)
{
	if (this.achievementservice)
		this.achievementservice.finishTest();
	this.getMessage('testfinished');
	if (callback)
		callback.invoke();
}
function ConditionHandleMap()
{
	this.initialCallbacks = new Array();
	this.permanentCallbacks = new Array();
}
ConditionHandleMap.prototype.addConditionHandle = function(handle)
{
	if (handle.isInitial())
	{
		var initialCallback = this.initialCallbacks[handle.getContentIdentifier()];
		;
		if (initialCallback == null || initialCallback == undefined)
		{
			initialCallback = new ConditionHandleMapCallback(handle.getContentIdentifier());
			this.initialCallbacks[handle.getContentIdentifier()] = initialCallback;
		}
		initialCallback.addHandle(handle);
	}
	else if (handle.isPermanent())
	{
		var permanentCallback = this.permanentCallbacks[handle.getContentIdentifier()];
		if (permanentCallback == null || permanentCallback == undefined)
		{
			permanentCallback = new ConditionHandleMapCallback(handle.getContentIdentifier());
			this.permanentCallbacks[handle.getContentIdentifier()] = permanentCallback;
		}
		permanentCallback.addHandle(handle);
	}
}
ConditionHandleMap.prototype.getInitialHandleCallbacks = function()
{
	return this.initialCallbacks;
}
ConditionHandleMap.prototype.getPermanentHandleCallbacks = function()
{
	return this.permanentCallbacks;
}
function ConditionHandleMapCallback(cid)
{
	;
	this.cid = cid;
	this.handles = new Array();
}
ConditionHandleMapCallback.prototype.addHandle = function(handle)
{
	;
	this.handles.push(handle);
}
ConditionHandleMapCallback.prototype.getContentIdentifier = function()
{
	return this.cid;
}
ConditionHandleMapCallback.prototype.invoke = function(scorestatistics)
{
	;
	for (var i = 0; i < this.handles.length; i++)
	{
		var statistic = new AchievementStatistic(null, null, null, scorestatistics);
		var handle = this.handles[i];
		;
		if (eval(statistic.parseFormula(handle.getCondition())))
		{
			;
			handle.getAction().invoke();
		}
	}
}
function ConditionHandle(action, cid, condition, initial, permanent)
{
	this.action = action;
	this.cid = cid;
	this.condition = condition;
	this.initial = initial;
	this.permanent = permanent;
}
ConditionHandle.prototype.getAction = function()
{
	return this.action;
}
ConditionHandle.prototype.getContentIdentifier = function()
{
	return this.cid;
}
ConditionHandle.prototype.getCondition = function()
{
	return this.condition;
}
ConditionHandle.prototype.isInitial = function()
{
	return this.initial;
}
ConditionHandle.prototype.isPermanent = function()
{
	return this.permanent;
}
